import typing

import android.content
import android.content.pm
import android.graphics.drawable
import android.os
import java
import java.chaquopy
import java.lang
import java.util
import java.util.concurrent

class SentenceSuggestionsInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SentenceSuggestionsInfo]] = ...
    @typing.overload
    def __init__(self, source: android.os.Parcel, /) -> None: ...
    @typing.overload
    def __init__(self, suggestionsInfos: java.chaquopy.JavaArray[SuggestionsInfo], offsets: java.chaquopy.JavaArrayJInt, lengths: java.chaquopy.JavaArrayJInt, /) -> None: ...
    def describeContents(self) -> int: ...
    def getLengthAt(self, i: int | java.jint | java.lang.Integer, /) -> int: ...
    def getOffsetAt(self, i: int | java.jint | java.lang.Integer, /) -> int: ...
    def getSuggestionsCount(self) -> int: ...
    def getSuggestionsInfoAt(self, i: int | java.jint | java.lang.Integer, /) -> SuggestionsInfo: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class SpellCheckerInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SpellCheckerInfo]] = ...
    def describeContents(self) -> int: ...
    def getComponent(self) -> android.content.ComponentName: ...
    def getId(self) -> str: ...
    def getPackageName(self) -> str: ...
    def getServiceInfo(self) -> android.content.pm.ServiceInfo: ...
    def getSettingsActivity(self) -> str: ...
    def getSubtypeAt(self, index: int | java.jint | java.lang.Integer, /) -> SpellCheckerSubtype: ...
    def getSubtypeCount(self) -> int: ...
    def loadIcon(self, pm: android.content.pm.PackageManager, /) -> android.graphics.drawable.Drawable: ...
    def loadLabel(self, pm: android.content.pm.PackageManager, /) -> java.lang.CharSequence: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class SpellCheckerSession(java.lang.Object):
    SERVICE_META_DATA: typing.ClassVar[str] = ...
    def cancel(self) -> None: ...
    def close(self) -> None: ...
    def finalize(self) -> None: ...
    def getSentenceSuggestions(self, textInfos: java.chaquopy.JavaArray[TextInfo], suggestionsLimit: int | java.jint | java.lang.Integer, /) -> None: ...
    def getSpellChecker(self) -> SpellCheckerInfo: ...
    @typing.overload
    def getSuggestions(self, textInfo: TextInfo, suggestionsLimit: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def getSuggestions(self, textInfos: java.chaquopy.JavaArray[TextInfo], suggestionsLimit: int | java.jint | java.lang.Integer, sequentialWords: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def isSessionDisconnected(self) -> bool: ...

    class SpellCheckerSessionParams(java.lang.Object):
        def getExtras(self) -> android.os.Bundle: ...
        def getLocale(self) -> java.util.Locale: ...
        def getSupportedAttributes(self) -> int: ...
        def shouldReferToSpellCheckerLanguageSettings(self) -> bool: ...

        class Builder(java.lang.Object):
            def __init__(self) -> None: ...
            def build(self) -> SpellCheckerSession.SpellCheckerSessionParams: ...
            def setExtras(self, extras: android.os.Bundle, /) -> SpellCheckerSession.SpellCheckerSessionParams.Builder: ...
            def setLocale(self, locale: java.util.Locale, /) -> SpellCheckerSession.SpellCheckerSessionParams.Builder: ...
            def setShouldReferToSpellCheckerLanguageSettings(self, shouldReferToSpellCheckerLanguageSettings: bool | java.jboolean | java.lang.Boolean, /) -> SpellCheckerSession.SpellCheckerSessionParams.Builder: ...
            def setSupportedAttributes(self, supportedAttributes: int | java.jint | java.lang.Integer, /) -> SpellCheckerSession.SpellCheckerSessionParams.Builder: ...

    class SpellCheckerSessionListener(java.lang.Object):
        def onGetSentenceSuggestions(self, arg1: java.chaquopy.JavaArray[SentenceSuggestionsInfo], /) -> None: ...
        def onGetSuggestions(self, arg1: java.chaquopy.JavaArray[SuggestionsInfo], /) -> None: ...

class SpellCheckerSubtype(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SpellCheckerSubtype]] = ...
    def __init__(self, nameId: int | java.jint | java.lang.Integer, locale: str | java.lang.String, extraValue: str | java.lang.String, /) -> None: ...
    def containsExtraValueKey(self, key: str | java.lang.String, /) -> bool: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getDisplayName(self, context: android.content.Context, packageName: str | java.lang.String, appInfo: android.content.pm.ApplicationInfo, /) -> java.lang.CharSequence: ...
    def getExtraValue(self) -> str: ...
    def getExtraValueOf(self, key: str | java.lang.String, /) -> str: ...
    def getLanguageTag(self) -> str: ...
    def getLocale(self) -> str: ...
    def getNameResId(self) -> int: ...
    def hashCode(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, parcelableFlags: int | java.jint | java.lang.Integer, /) -> None: ...

class SuggestionsInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SuggestionsInfo]] = ...
    RESULT_ATTR_DONT_SHOW_UI_FOR_SUGGESTIONS: typing.ClassVar[int] = ...
    RESULT_ATTR_HAS_RECOMMENDED_SUGGESTIONS: typing.ClassVar[int] = ...
    RESULT_ATTR_IN_THE_DICTIONARY: typing.ClassVar[int] = ...
    RESULT_ATTR_LOOKS_LIKE_GRAMMAR_ERROR: typing.ClassVar[int] = ...
    RESULT_ATTR_LOOKS_LIKE_TYPO: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, source: android.os.Parcel, /) -> None: ...
    @typing.overload
    def __init__(self, suggestionsAttributes: int | java.jint | java.lang.Integer, suggestions: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    @typing.overload
    def __init__(self, suggestionsAttributes: int | java.jint | java.lang.Integer, suggestions: java.chaquopy.JavaArray[java.lang.String], cookie: int | java.jint | java.lang.Integer, sequence: int | java.jint | java.lang.Integer, /) -> None: ...
    def describeContents(self) -> int: ...
    def getCookie(self) -> int: ...
    def getSequence(self) -> int: ...
    def getSuggestionAt(self, i: int | java.jint | java.lang.Integer, /) -> str: ...
    def getSuggestionsAttributes(self) -> int: ...
    def getSuggestionsCount(self) -> int: ...
    def setCookieAndSequence(self, cookie: int | java.jint | java.lang.Integer, sequence: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class TextInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[TextInfo]] = ...
    @typing.overload
    def __init__(self, source: android.os.Parcel, /) -> None: ...
    @typing.overload
    def __init__(self, text: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, text: str | java.lang.String, cookie: int | java.jint | java.lang.Integer, sequenceNumber: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, charSequence: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, cookie: int | java.jint | java.lang.Integer, sequenceNumber: int | java.jint | java.lang.Integer, /) -> None: ...
    def describeContents(self) -> int: ...
    def getCharSequence(self) -> java.lang.CharSequence: ...
    def getCookie(self) -> int: ...
    def getSequence(self) -> int: ...
    def getText(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class TextServicesManager(java.lang.Object):
    def getCurrentSpellCheckerInfo(self) -> SpellCheckerInfo | None: ...
    def getEnabledSpellCheckerInfos(self) -> java.util.List[SpellCheckerInfo]: ...
    def isSpellCheckerEnabled(self) -> bool: ...
    @typing.overload
    def newSpellCheckerSession(self, params: SpellCheckerSession.SpellCheckerSessionParams, executor: java.util.concurrent.Executor, listener: SpellCheckerSession.SpellCheckerSessionListener, /) -> SpellCheckerSession | None: ...
    @typing.overload
    def newSpellCheckerSession(self, bundle: android.os.Bundle, locale: java.util.Locale, listener: SpellCheckerSession.SpellCheckerSessionListener, referToSpellCheckerLanguageSettings: bool | java.jboolean | java.lang.Boolean, /) -> SpellCheckerSession | None: ...



import typing

import android.app
import android.content
import android.content.pm
import android.graphics
import android.graphics.drawable
import android.net
import android.net.wifi
import android.os
import android.security
import android.security.keystore
import android.telephony.data
import android.util
import java
import java.chaquopy
import java.lang
import java.net
import java.security
import java.security.cert
import java.time
import java.util
import java.util.concurrent
import java.util.function

class ConnectEvent(NetworkEvent, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ConnectEvent]] = ...
    def describeContents(self) -> int: ...
    def getInetAddress(self) -> java.net.InetAddress: ...
    def getPort(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class DelegatedAdminReceiver(android.content.BroadcastReceiver):
    def __init__(self) -> None: ...
    def onChoosePrivateKeyAlias(self, context: android.content.Context, intent: android.content.Intent, uid: int | java.jint | java.lang.Integer, uri: android.net.Uri, alias: str | java.lang.String, /) -> str | None: ...
    def onNetworkLogsAvailable(self, context: android.content.Context, intent: android.content.Intent, batchToken: int | java.jlong | java.lang.Long, networkLogsCount: int | java.jint | java.lang.Integer, /) -> None: ...
    def onReceive(self, context: android.content.Context, intent: android.content.Intent, /) -> None: ...
    def onSecurityLogsAvailable(self, context: android.content.Context, intent: android.content.Intent, /) -> None: ...

class DeviceAdminInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[DeviceAdminInfo]] = ...
    HEADLESS_DEVICE_OWNER_MODE_AFFILIATED: typing.ClassVar[int] = ...
    HEADLESS_DEVICE_OWNER_MODE_SINGLE_USER: typing.ClassVar[int] = ...
    HEADLESS_DEVICE_OWNER_MODE_UNSUPPORTED: typing.ClassVar[int] = ...
    USES_ENCRYPTED_STORAGE: typing.ClassVar[int] = ...
    USES_POLICY_DISABLE_CAMERA: typing.ClassVar[int] = ...
    USES_POLICY_DISABLE_KEYGUARD_FEATURES: typing.ClassVar[int] = ...
    USES_POLICY_EXPIRE_PASSWORD: typing.ClassVar[int] = ...
    USES_POLICY_FORCE_LOCK: typing.ClassVar[int] = ...
    USES_POLICY_LIMIT_PASSWORD: typing.ClassVar[int] = ...
    USES_POLICY_RESET_PASSWORD: typing.ClassVar[int] = ...
    USES_POLICY_WATCH_LOGIN: typing.ClassVar[int] = ...
    USES_POLICY_WIPE_DATA: typing.ClassVar[int] = ...
    def __init__(self, context: android.content.Context, resolveInfo: android.content.pm.ResolveInfo, /) -> None: ...
    def describeContents(self) -> int: ...
    def dump(self, pw: android.util.Printer, prefix: str | java.lang.String, /) -> None: ...
    def getActivityInfo(self) -> android.content.pm.ActivityInfo: ...
    def getComponent(self) -> android.content.ComponentName: ...
    def getHeadlessDeviceOwnerMode(self) -> int: ...
    def getPackageName(self) -> str: ...
    def getReceiverName(self) -> str: ...
    def getTagForPolicy(self, policyIdent: int | java.jint | java.lang.Integer, /) -> str: ...
    def isVisible(self) -> bool: ...
    def loadDescription(self, pm: android.content.pm.PackageManager, /) -> java.lang.CharSequence: ...
    def loadIcon(self, pm: android.content.pm.PackageManager, /) -> android.graphics.drawable.Drawable: ...
    def loadLabel(self, pm: android.content.pm.PackageManager, /) -> java.lang.CharSequence: ...
    def supportsTransferOwnership(self) -> bool: ...
    def toString(self) -> str: ...
    def usesPolicy(self, policyIdent: int | java.jint | java.lang.Integer, /) -> bool: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class DeviceAdminReceiver(android.content.BroadcastReceiver):
    ACTION_CHOOSE_PRIVATE_KEY_ALIAS: typing.ClassVar[str] = ...
    ACTION_DEVICE_ADMIN_DISABLED: typing.ClassVar[str] = ...
    ACTION_DEVICE_ADMIN_DISABLE_REQUESTED: typing.ClassVar[str] = ...
    ACTION_DEVICE_ADMIN_ENABLED: typing.ClassVar[str] = ...
    ACTION_LOCK_TASK_ENTERING: typing.ClassVar[str] = ...
    ACTION_LOCK_TASK_EXITING: typing.ClassVar[str] = ...
    ACTION_NETWORK_LOGS_AVAILABLE: typing.ClassVar[str] = ...
    ACTION_PASSWORD_CHANGED: typing.ClassVar[str] = ...
    ACTION_PASSWORD_EXPIRING: typing.ClassVar[str] = ...
    ACTION_PASSWORD_FAILED: typing.ClassVar[str] = ...
    ACTION_PASSWORD_SUCCEEDED: typing.ClassVar[str] = ...
    ACTION_PROFILE_PROVISIONING_COMPLETE: typing.ClassVar[str] = ...
    ACTION_SECURITY_LOGS_AVAILABLE: typing.ClassVar[str] = ...
    BUGREPORT_FAILURE_FAILED_COMPLETING: typing.ClassVar[int] = ...
    BUGREPORT_FAILURE_FILE_NO_LONGER_AVAILABLE: typing.ClassVar[int] = ...
    DEVICE_ADMIN_META_DATA: typing.ClassVar[str] = ...
    EXTRA_DISABLE_WARNING: typing.ClassVar[str] = ...
    EXTRA_LOCK_TASK_PACKAGE: typing.ClassVar[str] = ...
    EXTRA_TRANSFER_OWNERSHIP_ADMIN_EXTRAS_BUNDLE: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    def getManager(self, context: android.content.Context, /) -> DevicePolicyManager: ...
    def getWho(self, context: android.content.Context, /) -> android.content.ComponentName: ...
    def onBugreportFailed(self, context: android.content.Context, intent: android.content.Intent, failureCode: int | java.jint | java.lang.Integer, /) -> None: ...
    def onBugreportShared(self, context: android.content.Context, intent: android.content.Intent, bugreportHash: str | java.lang.String, /) -> None: ...
    def onBugreportSharingDeclined(self, context: android.content.Context, intent: android.content.Intent, /) -> None: ...
    def onChoosePrivateKeyAlias(self, context: android.content.Context, intent: android.content.Intent, uid: int | java.jint | java.lang.Integer, uri: android.net.Uri, alias: str | java.lang.String, /) -> str | None: ...
    def onComplianceAcknowledgementRequired(self, context: android.content.Context, intent: android.content.Intent, /) -> None: ...
    def onDisableRequested(self, context: android.content.Context, intent: android.content.Intent, /) -> java.lang.CharSequence | None: ...
    def onDisabled(self, context: android.content.Context, intent: android.content.Intent, /) -> None: ...
    def onEnabled(self, context: android.content.Context, intent: android.content.Intent, /) -> None: ...
    def onLockTaskModeEntering(self, context: android.content.Context, intent: android.content.Intent, pkg: str | java.lang.String, /) -> None: ...
    def onLockTaskModeExiting(self, context: android.content.Context, intent: android.content.Intent, /) -> None: ...
    def onNetworkLogsAvailable(self, context: android.content.Context, intent: android.content.Intent, batchToken: int | java.jlong | java.lang.Long, networkLogsCount: int | java.jint | java.lang.Integer, /) -> None: ...
    def onOperationSafetyStateChanged(self, context: android.content.Context, reason: int | java.jint | java.lang.Integer, isSafe: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def onPasswordChanged(self, context: android.content.Context, intent: android.content.Intent, /) -> None: ...
    @typing.overload
    def onPasswordChanged(self, context: android.content.Context, intent: android.content.Intent, user: android.os.UserHandle, /) -> None: ...
    @typing.overload
    def onPasswordExpiring(self, context: android.content.Context, intent: android.content.Intent, /) -> None: ...
    @typing.overload
    def onPasswordExpiring(self, context: android.content.Context, intent: android.content.Intent, user: android.os.UserHandle, /) -> None: ...
    @typing.overload
    def onPasswordFailed(self, context: android.content.Context, intent: android.content.Intent, /) -> None: ...
    @typing.overload
    def onPasswordFailed(self, context: android.content.Context, intent: android.content.Intent, user: android.os.UserHandle, /) -> None: ...
    @typing.overload
    def onPasswordSucceeded(self, context: android.content.Context, intent: android.content.Intent, /) -> None: ...
    @typing.overload
    def onPasswordSucceeded(self, context: android.content.Context, intent: android.content.Intent, user: android.os.UserHandle, /) -> None: ...
    def onProfileProvisioningComplete(self, context: android.content.Context, intent: android.content.Intent, /) -> None: ...
    def onReadyForUserInitialization(self, context: android.content.Context, intent: android.content.Intent, /) -> None: ...
    def onReceive(self, context: android.content.Context, intent: android.content.Intent, /) -> None: ...
    def onSecurityLogsAvailable(self, context: android.content.Context, intent: android.content.Intent, /) -> None: ...
    def onSystemUpdatePending(self, context: android.content.Context, intent: android.content.Intent, receivedTime: int | java.jlong | java.lang.Long, /) -> None: ...
    def onTransferAffiliatedProfileOwnershipComplete(self, context: android.content.Context, user: android.os.UserHandle, /) -> None: ...
    def onTransferOwnershipComplete(self, context: android.content.Context, bundle: android.os.PersistableBundle, /) -> None: ...
    def onUserAdded(self, context: android.content.Context, intent: android.content.Intent, addedUser: android.os.UserHandle, /) -> None: ...
    def onUserRemoved(self, context: android.content.Context, intent: android.content.Intent, removedUser: android.os.UserHandle, /) -> None: ...
    def onUserStarted(self, context: android.content.Context, intent: android.content.Intent, startedUser: android.os.UserHandle, /) -> None: ...
    def onUserStopped(self, context: android.content.Context, intent: android.content.Intent, stoppedUser: android.os.UserHandle, /) -> None: ...
    def onUserSwitched(self, context: android.content.Context, intent: android.content.Intent, switchedUser: android.os.UserHandle, /) -> None: ...

class DeviceAdminService(android.app.Service):
    def __init__(self) -> None: ...
    def onBind(self, intent: android.content.Intent, /) -> android.os.IBinder: ...

class DevicePolicyIdentifiers(java.lang.Object):
    ACCOUNT_MANAGEMENT_DISABLED_POLICY: typing.ClassVar[str] = ...
    APPLICATION_HIDDEN_POLICY: typing.ClassVar[str] = ...
    APPLICATION_RESTRICTIONS_POLICY: typing.ClassVar[str] = ...
    APP_FUNCTIONS_POLICY: typing.ClassVar[str] = ...
    AUTO_TIMEZONE_POLICY: typing.ClassVar[str] = ...
    AUTO_TIME_POLICY: typing.ClassVar[str] = ...
    BACKUP_SERVICE_POLICY: typing.ClassVar[str] = ...
    CAMERA_DISABLED_POLICY: typing.ClassVar[str] = ...
    CONTENT_PROTECTION_POLICY: typing.ClassVar[str] = ...
    KEYGUARD_DISABLED_FEATURES_POLICY: typing.ClassVar[str] = ...
    LOCK_TASK_POLICY: typing.ClassVar[str] = ...
    PACKAGES_SUSPENDED_POLICY: typing.ClassVar[str] = ...
    PACKAGE_UNINSTALL_BLOCKED_POLICY: typing.ClassVar[str] = ...
    PASSWORD_COMPLEXITY_POLICY: typing.ClassVar[str] = ...
    PERMISSION_GRANT_POLICY: typing.ClassVar[str] = ...
    PERSISTENT_PREFERRED_ACTIVITY_POLICY: typing.ClassVar[str] = ...
    RESET_PASSWORD_TOKEN_POLICY: typing.ClassVar[str] = ...
    SECURITY_LOGGING_POLICY: typing.ClassVar[str] = ...
    STATUS_BAR_DISABLED_POLICY: typing.ClassVar[str] = ...
    USB_DATA_SIGNALING_POLICY: typing.ClassVar[str] = ...
    USER_CONTROL_DISABLED_PACKAGES_POLICY: typing.ClassVar[str] = ...
    @staticmethod
    def getIdentifierForUserRestriction(restriction: str | java.lang.String, /) -> str: ...

class DevicePolicyManager(java.lang.Object):
    ACTION_ADD_DEVICE_ADMIN: typing.ClassVar[str] = ...
    ACTION_ADMIN_POLICY_COMPLIANCE: typing.ClassVar[str] = ...
    ACTION_APPLICATION_DELEGATION_SCOPES_CHANGED: typing.ClassVar[str] = ...
    ACTION_CHECK_POLICY_COMPLIANCE: typing.ClassVar[str] = ...
    ACTION_DEVICE_ADMIN_SERVICE: typing.ClassVar[str] = ...
    ACTION_DEVICE_FINANCING_STATE_CHANGED: typing.ClassVar[str] = ...
    ACTION_DEVICE_OWNER_CHANGED: typing.ClassVar[str] = ...
    ACTION_DEVICE_POLICY_RESOURCE_UPDATED: typing.ClassVar[str] = ...
    ACTION_GET_PROVISIONING_MODE: typing.ClassVar[str] = ...
    ACTION_MANAGED_PROFILE_PROVISIONED: typing.ClassVar[str] = ...
    ACTION_PROFILE_OWNER_CHANGED: typing.ClassVar[str] = ...
    ACTION_PROVISIONING_SUCCESSFUL: typing.ClassVar[str] = ...
    ACTION_PROVISION_MANAGED_DEVICE: typing.ClassVar[str] = ...
    ACTION_PROVISION_MANAGED_PROFILE: typing.ClassVar[str] = ...
    ACTION_SET_NEW_PARENT_PROFILE_PASSWORD: typing.ClassVar[str] = ...
    ACTION_SET_NEW_PASSWORD: typing.ClassVar[str] = ...
    ACTION_START_ENCRYPTION: typing.ClassVar[str] = ...
    ACTION_SYSTEM_UPDATE_POLICY_CHANGED: typing.ClassVar[str] = ...
    APP_FUNCTIONS_DISABLED: typing.ClassVar[int] = ...
    APP_FUNCTIONS_DISABLED_CROSS_PROFILE: typing.ClassVar[int] = ...
    APP_FUNCTIONS_NOT_CONTROLLED_BY_POLICY: typing.ClassVar[int] = ...
    AUTO_TIME_DISABLED: typing.ClassVar[int] = ...
    AUTO_TIME_ENABLED: typing.ClassVar[int] = ...
    AUTO_TIME_NOT_CONTROLLED_BY_POLICY: typing.ClassVar[int] = ...
    AUTO_TIME_ZONE_DISABLED: typing.ClassVar[int] = ...
    AUTO_TIME_ZONE_ENABLED: typing.ClassVar[int] = ...
    AUTO_TIME_ZONE_NOT_CONTROLLED_BY_POLICY: typing.ClassVar[int] = ...
    CONTENT_PROTECTION_DISABLED: typing.ClassVar[int] = ...
    CONTENT_PROTECTION_ENABLED: typing.ClassVar[int] = ...
    CONTENT_PROTECTION_NOT_CONTROLLED_BY_POLICY: typing.ClassVar[int] = ...
    DELEGATION_APP_RESTRICTIONS: typing.ClassVar[str] = ...
    DELEGATION_BLOCK_UNINSTALL: typing.ClassVar[str] = ...
    DELEGATION_CERT_INSTALL: typing.ClassVar[str] = ...
    DELEGATION_CERT_SELECTION: typing.ClassVar[str] = ...
    DELEGATION_ENABLE_SYSTEM_APP: typing.ClassVar[str] = ...
    DELEGATION_INSTALL_EXISTING_PACKAGE: typing.ClassVar[str] = ...
    DELEGATION_KEEP_UNINSTALLED_PACKAGES: typing.ClassVar[str] = ...
    DELEGATION_NETWORK_LOGGING: typing.ClassVar[str] = ...
    DELEGATION_PACKAGE_ACCESS: typing.ClassVar[str] = ...
    DELEGATION_PERMISSION_GRANT: typing.ClassVar[str] = ...
    DELEGATION_SECURITY_LOGGING: typing.ClassVar[str] = ...
    ENCRYPTION_STATUS_ACTIVATING: typing.ClassVar[int] = ...
    ENCRYPTION_STATUS_ACTIVE: typing.ClassVar[int] = ...
    ENCRYPTION_STATUS_ACTIVE_DEFAULT_KEY: typing.ClassVar[int] = ...
    ENCRYPTION_STATUS_ACTIVE_PER_USER: typing.ClassVar[int] = ...
    ENCRYPTION_STATUS_INACTIVE: typing.ClassVar[int] = ...
    ENCRYPTION_STATUS_UNSUPPORTED: typing.ClassVar[int] = ...
    EXTRA_ADD_EXPLANATION: typing.ClassVar[str] = ...
    EXTRA_DELEGATION_SCOPES: typing.ClassVar[str] = ...
    EXTRA_DEVICE_ADMIN: typing.ClassVar[str] = ...
    EXTRA_DEVICE_PASSWORD_REQUIREMENT_ONLY: typing.ClassVar[str] = ...
    EXTRA_PASSWORD_COMPLEXITY: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_ACCOUNT_TO_MIGRATE: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_ADMIN_EXTRAS_BUNDLE: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_ALLOWED_PROVISIONING_MODES: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_ALLOW_OFFLINE: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_DEVICE_ADMIN_COMPONENT_NAME: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_DEVICE_ADMIN_MINIMUM_VERSION_CODE: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_DEVICE_ADMIN_PACKAGE_CHECKSUM: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_DEVICE_ADMIN_PACKAGE_DOWNLOAD_COOKIE_HEADER: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_DEVICE_ADMIN_PACKAGE_DOWNLOAD_LOCATION: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_DEVICE_ADMIN_PACKAGE_NAME: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_DEVICE_ADMIN_SIGNATURE_CHECKSUM: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_DISCLAIMERS: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_DISCLAIMER_CONTENT: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_DISCLAIMER_HEADER: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_EMAIL_ADDRESS: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_IMEI: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_KEEP_ACCOUNT_ON_MIGRATION: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_KEEP_SCREEN_ON: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_LEAVE_ALL_SYSTEM_APPS_ENABLED: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_LOCALE: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_LOCAL_TIME: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_LOGO_URI: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_MAIN_COLOR: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_MODE: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_SENSORS_PERMISSION_GRANT_OPT_OUT: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_SERIAL_NUMBER: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_SHOULD_LAUNCH_RESULT_INTENT: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_SKIP_EDUCATION_SCREENS: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_SKIP_ENCRYPTION: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_SKIP_USER_CONSENT: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_TIME_ZONE: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_USE_MOBILE_DATA: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_WIFI_ANONYMOUS_IDENTITY: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_WIFI_CA_CERTIFICATE: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_WIFI_DOMAIN: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_WIFI_EAP_METHOD: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_WIFI_HIDDEN: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_WIFI_IDENTITY: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_WIFI_PAC_URL: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_WIFI_PASSWORD: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_WIFI_PHASE2_AUTH: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_WIFI_PROXY_BYPASS: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_WIFI_PROXY_HOST: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_WIFI_PROXY_PORT: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_WIFI_SECURITY_TYPE: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_WIFI_SSID: typing.ClassVar[str] = ...
    EXTRA_PROVISIONING_WIFI_USER_CERTIFICATE: typing.ClassVar[str] = ...
    EXTRA_RESOURCE_IDS: typing.ClassVar[str] = ...
    EXTRA_RESOURCE_TYPE: typing.ClassVar[str] = ...
    EXTRA_RESOURCE_TYPE_DRAWABLE: typing.ClassVar[int] = ...
    EXTRA_RESOURCE_TYPE_STRING: typing.ClassVar[int] = ...
    EXTRA_RESULT_LAUNCH_INTENT: typing.ClassVar[str] = ...
    FLAG_EVICT_CREDENTIAL_ENCRYPTION_KEY: typing.ClassVar[int] = ...
    FLAG_MANAGED_CAN_ACCESS_PARENT: typing.ClassVar[int] = ...
    FLAG_PARENT_CAN_ACCESS_MANAGED: typing.ClassVar[int] = ...
    ID_TYPE_BASE_INFO: typing.ClassVar[int] = ...
    ID_TYPE_IMEI: typing.ClassVar[int] = ...
    ID_TYPE_INDIVIDUAL_ATTESTATION: typing.ClassVar[int] = ...
    ID_TYPE_MEID: typing.ClassVar[int] = ...
    ID_TYPE_SERIAL: typing.ClassVar[int] = ...
    INSTALLKEY_REQUEST_CREDENTIALS_ACCESS: typing.ClassVar[int] = ...
    INSTALLKEY_SET_USER_SELECTABLE: typing.ClassVar[int] = ...
    KEYGUARD_DISABLE_BIOMETRICS: typing.ClassVar[int] = ...
    KEYGUARD_DISABLE_FACE: typing.ClassVar[int] = ...
    KEYGUARD_DISABLE_FEATURES_ALL: typing.ClassVar[int] = ...
    KEYGUARD_DISABLE_FEATURES_NONE: typing.ClassVar[int] = ...
    KEYGUARD_DISABLE_FINGERPRINT: typing.ClassVar[int] = ...
    KEYGUARD_DISABLE_IRIS: typing.ClassVar[int] = ...
    KEYGUARD_DISABLE_REMOTE_INPUT: typing.ClassVar[int] = ...
    KEYGUARD_DISABLE_SECURE_CAMERA: typing.ClassVar[int] = ...
    KEYGUARD_DISABLE_SECURE_NOTIFICATIONS: typing.ClassVar[int] = ...
    KEYGUARD_DISABLE_SHORTCUTS_ALL: typing.ClassVar[int] = ...
    KEYGUARD_DISABLE_TRUST_AGENTS: typing.ClassVar[int] = ...
    KEYGUARD_DISABLE_UNREDACTED_NOTIFICATIONS: typing.ClassVar[int] = ...
    KEYGUARD_DISABLE_WIDGETS_ALL: typing.ClassVar[int] = ...
    LEAVE_ALL_SYSTEM_APPS_ENABLED: typing.ClassVar[int] = ...
    LOCK_TASK_FEATURE_BLOCK_ACTIVITY_START_IN_TASK: typing.ClassVar[int] = ...
    LOCK_TASK_FEATURE_GLOBAL_ACTIONS: typing.ClassVar[int] = ...
    LOCK_TASK_FEATURE_HOME: typing.ClassVar[int] = ...
    LOCK_TASK_FEATURE_KEYGUARD: typing.ClassVar[int] = ...
    LOCK_TASK_FEATURE_NONE: typing.ClassVar[int] = ...
    LOCK_TASK_FEATURE_NOTIFICATIONS: typing.ClassVar[int] = ...
    LOCK_TASK_FEATURE_OVERVIEW: typing.ClassVar[int] = ...
    LOCK_TASK_FEATURE_SYSTEM_INFO: typing.ClassVar[int] = ...
    MAKE_USER_EPHEMERAL: typing.ClassVar[int] = ...
    MIME_TYPE_PROVISIONING_NFC: typing.ClassVar[str] = ...
    MTE_DISABLED: typing.ClassVar[int] = ...
    MTE_ENABLED: typing.ClassVar[int] = ...
    MTE_NOT_CONTROLLED_BY_POLICY: typing.ClassVar[int] = ...
    NEARBY_STREAMING_DISABLED: typing.ClassVar[int] = ...
    NEARBY_STREAMING_ENABLED: typing.ClassVar[int] = ...
    NEARBY_STREAMING_NOT_CONTROLLED_BY_POLICY: typing.ClassVar[int] = ...
    NEARBY_STREAMING_SAME_MANAGED_ACCOUNT_ONLY: typing.ClassVar[int] = ...
    OPERATION_SAFETY_REASON_DRIVING_DISTRACTION: typing.ClassVar[int] = ...
    PASSWORD_COMPLEXITY_HIGH: typing.ClassVar[int] = ...
    PASSWORD_COMPLEXITY_LOW: typing.ClassVar[int] = ...
    PASSWORD_COMPLEXITY_MEDIUM: typing.ClassVar[int] = ...
    PASSWORD_COMPLEXITY_NONE: typing.ClassVar[int] = ...
    PASSWORD_QUALITY_ALPHABETIC: typing.ClassVar[int] = ...
    PASSWORD_QUALITY_ALPHANUMERIC: typing.ClassVar[int] = ...
    PASSWORD_QUALITY_BIOMETRIC_WEAK: typing.ClassVar[int] = ...
    PASSWORD_QUALITY_COMPLEX: typing.ClassVar[int] = ...
    PASSWORD_QUALITY_NUMERIC: typing.ClassVar[int] = ...
    PASSWORD_QUALITY_NUMERIC_COMPLEX: typing.ClassVar[int] = ...
    PASSWORD_QUALITY_SOMETHING: typing.ClassVar[int] = ...
    PASSWORD_QUALITY_UNSPECIFIED: typing.ClassVar[int] = ...
    PERMISSION_GRANT_STATE_DEFAULT: typing.ClassVar[int] = ...
    PERMISSION_GRANT_STATE_DENIED: typing.ClassVar[int] = ...
    PERMISSION_GRANT_STATE_GRANTED: typing.ClassVar[int] = ...
    PERMISSION_POLICY_AUTO_DENY: typing.ClassVar[int] = ...
    PERMISSION_POLICY_AUTO_GRANT: typing.ClassVar[int] = ...
    PERMISSION_POLICY_PROMPT: typing.ClassVar[int] = ...
    PERSONAL_APPS_NOT_SUSPENDED: typing.ClassVar[int] = ...
    PERSONAL_APPS_SUSPENDED_EXPLICITLY: typing.ClassVar[int] = ...
    PERSONAL_APPS_SUSPENDED_PROFILE_TIMEOUT: typing.ClassVar[int] = ...
    POLICY_DISABLE_CAMERA: typing.ClassVar[str] = ...
    POLICY_DISABLE_SCREEN_CAPTURE: typing.ClassVar[str] = ...
    PRIVATE_DNS_MODE_OFF: typing.ClassVar[int] = ...
    PRIVATE_DNS_MODE_OPPORTUNISTIC: typing.ClassVar[int] = ...
    PRIVATE_DNS_MODE_PROVIDER_HOSTNAME: typing.ClassVar[int] = ...
    PRIVATE_DNS_MODE_UNKNOWN: typing.ClassVar[int] = ...
    PRIVATE_DNS_SET_ERROR_FAILURE_SETTING: typing.ClassVar[int] = ...
    PRIVATE_DNS_SET_ERROR_HOST_NOT_SERVING: typing.ClassVar[int] = ...
    PRIVATE_DNS_SET_NO_ERROR: typing.ClassVar[int] = ...
    PROVISIONING_MODE_FULLY_MANAGED_DEVICE: typing.ClassVar[int] = ...
    PROVISIONING_MODE_MANAGED_PROFILE: typing.ClassVar[int] = ...
    PROVISIONING_MODE_MANAGED_PROFILE_ON_PERSONAL_DEVICE: typing.ClassVar[int] = ...
    RESET_PASSWORD_DO_NOT_ASK_CREDENTIALS_ON_BOOT: typing.ClassVar[int] = ...
    RESET_PASSWORD_REQUIRE_ENTRY: typing.ClassVar[int] = ...
    SKIP_SETUP_WIZARD: typing.ClassVar[int] = ...
    WIFI_SECURITY_ENTERPRISE_192: typing.ClassVar[int] = ...
    WIFI_SECURITY_ENTERPRISE_EAP: typing.ClassVar[int] = ...
    WIFI_SECURITY_OPEN: typing.ClassVar[int] = ...
    WIFI_SECURITY_PERSONAL: typing.ClassVar[int] = ...
    WIPE_EUICC: typing.ClassVar[int] = ...
    WIPE_EXTERNAL_STORAGE: typing.ClassVar[int] = ...
    WIPE_RESET_PROTECTION_DATA: typing.ClassVar[int] = ...
    WIPE_SILENTLY: typing.ClassVar[int] = ...
    def acknowledgeDeviceCompliant(self) -> None: ...
    def addCrossProfileIntentFilter(self, admin: android.content.ComponentName, filter: android.content.IntentFilter, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def addCrossProfileWidgetProvider(self, admin: android.content.ComponentName, packageName: str | java.lang.String, /) -> bool: ...
    def addOverrideApn(self, admin: android.content.ComponentName, apnSetting: android.telephony.data.ApnSetting, /) -> int: ...
    def addPersistentPreferredActivity(self, admin: android.content.ComponentName, filter: android.content.IntentFilter, activity: android.content.ComponentName, /) -> None: ...
    def addUserRestriction(self, admin: android.content.ComponentName, key: str | java.lang.String, /) -> None: ...
    def addUserRestrictionGlobally(self, key: str | java.lang.String, /) -> None: ...
    @typing.overload
    def bindDeviceAdminServiceAsUser(self, admin: android.content.ComponentName, serviceIntent: android.content.Intent, conn: android.content.ServiceConnection, flags: int | java.jint | java.lang.Integer, targetUser: android.os.UserHandle, /) -> bool: ...
    @typing.overload
    def bindDeviceAdminServiceAsUser(self, admin: android.content.ComponentName, serviceIntent: android.content.Intent, conn: android.content.ServiceConnection, flags: android.content.Context.BindServiceFlags, targetUser: android.os.UserHandle, /) -> bool: ...
    def canAdminGrantSensorsPermissions(self) -> bool: ...
    def canUsbDataSignalingBeDisabled(self) -> bool: ...
    def clearApplicationUserData(self, admin: android.content.ComponentName, packageName: str | java.lang.String, executor: java.util.concurrent.Executor, listener: DevicePolicyManager.OnClearApplicationUserDataListener, /) -> None: ...
    def clearCrossProfileIntentFilters(self, admin: android.content.ComponentName, /) -> None: ...
    def clearDeviceOwnerApp(self, packageName: str | java.lang.String, /) -> None: ...
    def clearPackagePersistentPreferredActivities(self, admin: android.content.ComponentName, packageName: str | java.lang.String, /) -> None: ...
    def clearProfileOwner(self, admin: android.content.ComponentName, /) -> None: ...
    def clearResetPasswordToken(self, admin: android.content.ComponentName, /) -> bool: ...
    def clearUserRestriction(self, admin: android.content.ComponentName, key: str | java.lang.String, /) -> None: ...
    def createAdminSupportIntent(self, restriction: str | java.lang.String, /) -> android.content.Intent | None: ...
    def createAndManageUser(self, admin: android.content.ComponentName, name: str | java.lang.String, profileOwner: android.content.ComponentName, adminExtras: android.os.PersistableBundle, flags: int | java.jint | java.lang.Integer, /) -> android.os.UserHandle | None: ...
    @typing.overload
    def enableSystemApp(self, admin: android.content.ComponentName, intent: android.content.Intent, /) -> int: ...
    @typing.overload
    def enableSystemApp(self, admin: android.content.ComponentName, packageName: str | java.lang.String, /) -> None: ...
    def generateKeyPair(self, admin: android.content.ComponentName, algorithm: str | java.lang.String, keySpec: android.security.keystore.KeyGenParameterSpec, idAttestationFlags: int | java.jint | java.lang.Integer, /) -> android.security.AttestedKeyPair: ...
    def getAccountTypesWithManagementDisabled(self) -> java.chaquopy.JavaArray[java.lang.String] | None: ...
    def getActiveAdmins(self) -> java.util.List[android.content.ComponentName] | None: ...
    def getAffiliationIds(self, admin: android.content.ComponentName, /) -> java.util.Set[java.lang.String]: ...
    def getAlwaysOnVpnLockdownWhitelist(self, admin: android.content.ComponentName, /) -> java.util.Set[java.lang.String] | None: ...
    def getAlwaysOnVpnPackage(self, admin: android.content.ComponentName, /) -> str | None: ...
    def getAppFunctionsPolicy(self) -> int: ...
    def getApplicationRestrictions(self, admin: android.content.ComponentName, packageName: str | java.lang.String, /) -> android.os.Bundle: ...
    def getApplicationRestrictionsManagingPackage(self, admin: android.content.ComponentName, /) -> str | None: ...
    def getAutoTimeEnabled(self, admin: android.content.ComponentName, /) -> bool: ...
    def getAutoTimePolicy(self) -> int: ...
    def getAutoTimeRequired(self) -> bool: ...
    def getAutoTimeZoneEnabled(self, admin: android.content.ComponentName, /) -> bool: ...
    def getAutoTimeZonePolicy(self) -> int: ...
    def getBindDeviceAdminTargetUsers(self, admin: android.content.ComponentName, /) -> java.util.List[android.os.UserHandle]: ...
    def getBluetoothContactSharingDisabled(self, admin: android.content.ComponentName, /) -> bool: ...
    def getCameraDisabled(self, admin: android.content.ComponentName, /) -> bool: ...
    def getCertInstallerPackage(self, admin: android.content.ComponentName, /) -> str | None: ...
    def getContentProtectionPolicy(self, admin: android.content.ComponentName, /) -> int: ...
    def getCredentialManagerPolicy(self) -> PackagePolicy | None: ...
    def getCrossProfileCalendarPackages(self, admin: android.content.ComponentName, /) -> java.util.Set[java.lang.String] | None: ...
    def getCrossProfileCallerIdDisabled(self, admin: android.content.ComponentName, /) -> bool: ...
    def getCrossProfileContactsSearchDisabled(self, admin: android.content.ComponentName, /) -> bool: ...
    def getCrossProfilePackages(self, admin: android.content.ComponentName, /) -> java.util.Set[java.lang.String]: ...
    def getCrossProfileWidgetProviders(self, admin: android.content.ComponentName, /) -> java.util.List[java.lang.String]: ...
    def getCurrentFailedPasswordAttempts(self) -> int: ...
    def getDelegatePackages(self, admin: android.content.ComponentName, delegationScope: str | java.lang.String, /) -> java.util.List[java.lang.String] | None: ...
    def getDelegatedScopes(self, admin: android.content.ComponentName, delegatedPackage: str | java.lang.String, /) -> java.util.List[java.lang.String]: ...
    def getDeviceOwnerLockScreenInfo(self) -> java.lang.CharSequence: ...
    def getDevicePolicyManagementRoleHolderPackage(self) -> str | None: ...
    def getEndUserSessionMessage(self, admin: android.content.ComponentName, /) -> java.lang.CharSequence: ...
    def getEnrollmentSpecificId(self) -> str: ...
    def getFactoryResetProtectionPolicy(self, admin: android.content.ComponentName, /) -> FactoryResetProtectionPolicy | None: ...
    def getGlobalPrivateDnsHost(self, admin: android.content.ComponentName, /) -> str | None: ...
    def getGlobalPrivateDnsMode(self, admin: android.content.ComponentName, /) -> int: ...
    def getInstalledCaCerts(self, admin: android.content.ComponentName, /) -> java.util.List[java.chaquopy.JavaArrayJByte]: ...
    def getKeepUninstalledPackages(self, admin: android.content.ComponentName, /) -> java.util.List[java.lang.String] | None: ...
    def getKeyPairGrants(self, alias: str | java.lang.String, /) -> java.util.Map[java.lang.Integer, java.util.Set[java.lang.String]]: ...
    def getKeyguardDisabledFeatures(self, admin: android.content.ComponentName, /) -> int: ...
    def getLockTaskFeatures(self, admin: android.content.ComponentName, /) -> int: ...
    def getLockTaskPackages(self, admin: android.content.ComponentName, /) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getLongSupportMessage(self, admin: android.content.ComponentName, /) -> java.lang.CharSequence | None: ...
    def getManagedProfileCallerIdAccessPolicy(self) -> PackagePolicy | None: ...
    def getManagedProfileContactsAccessPolicy(self) -> PackagePolicy | None: ...
    def getManagedProfileMaximumTimeOff(self, admin: android.content.ComponentName, /) -> int: ...
    def getManagedSubscriptionsPolicy(self) -> ManagedSubscriptionsPolicy: ...
    def getMaximumFailedPasswordsForWipe(self, admin: android.content.ComponentName, /) -> int: ...
    def getMaximumTimeToLock(self, admin: android.content.ComponentName, /) -> int: ...
    def getMeteredDataDisabledPackages(self, admin: android.content.ComponentName, /) -> java.util.List[java.lang.String]: ...
    def getMinimumRequiredWifiSecurityLevel(self) -> int: ...
    def getMtePolicy(self) -> int: ...
    def getNearbyAppStreamingPolicy(self) -> int: ...
    def getNearbyNotificationStreamingPolicy(self) -> int: ...
    def getOrganizationColor(self, admin: android.content.ComponentName, /) -> int: ...
    def getOrganizationName(self, admin: android.content.ComponentName, /) -> java.lang.CharSequence | None: ...
    def getOverrideApns(self, admin: android.content.ComponentName, /) -> java.util.List[android.telephony.data.ApnSetting]: ...
    def getParentProfileInstance(self, admin: android.content.ComponentName, /) -> DevicePolicyManager: ...
    def getPasswordComplexity(self) -> int: ...
    def getPasswordExpiration(self, admin: android.content.ComponentName, /) -> int: ...
    def getPasswordExpirationTimeout(self, admin: android.content.ComponentName, /) -> int: ...
    def getPasswordHistoryLength(self, admin: android.content.ComponentName, /) -> int: ...
    def getPasswordMaximumLength(self, quality: int | java.jint | java.lang.Integer, /) -> int: ...
    def getPasswordMinimumLength(self, admin: android.content.ComponentName, /) -> int: ...
    def getPasswordMinimumLetters(self, admin: android.content.ComponentName, /) -> int: ...
    def getPasswordMinimumLowerCase(self, admin: android.content.ComponentName, /) -> int: ...
    def getPasswordMinimumNonLetter(self, admin: android.content.ComponentName, /) -> int: ...
    def getPasswordMinimumNumeric(self, admin: android.content.ComponentName, /) -> int: ...
    def getPasswordMinimumSymbols(self, admin: android.content.ComponentName, /) -> int: ...
    def getPasswordMinimumUpperCase(self, admin: android.content.ComponentName, /) -> int: ...
    def getPasswordQuality(self, admin: android.content.ComponentName, /) -> int: ...
    def getPendingSystemUpdate(self, admin: android.content.ComponentName, /) -> SystemUpdateInfo | None: ...
    def getPermissionGrantState(self, admin: android.content.ComponentName, packageName: str | java.lang.String, permission: str | java.lang.String, /) -> int: ...
    def getPermissionPolicy(self, admin: android.content.ComponentName, /) -> int: ...
    def getPermittedAccessibilityServices(self, admin: android.content.ComponentName, /) -> java.util.List[java.lang.String] | None: ...
    def getPermittedCrossProfileNotificationListeners(self, admin: android.content.ComponentName, /) -> java.util.List[java.lang.String] | None: ...
    def getPermittedInputMethods(self, admin: android.content.ComponentName, /) -> java.util.List[java.lang.String] | None: ...
    def getPersonalAppsSuspendedReasons(self, admin: android.content.ComponentName, /) -> int: ...
    def getPreferentialNetworkServiceConfigs(self) -> java.util.List[PreferentialNetworkServiceConfig]: ...
    def getRequiredPasswordComplexity(self) -> int: ...
    def getRequiredStrongAuthTimeout(self, admin: android.content.ComponentName, /) -> int: ...
    def getResources(self) -> DevicePolicyResourcesManager: ...
    def getScreenCaptureDisabled(self, admin: android.content.ComponentName, /) -> bool: ...
    def getSecondaryUsers(self, admin: android.content.ComponentName, /) -> java.util.List[android.os.UserHandle]: ...
    def getShortSupportMessage(self, admin: android.content.ComponentName, /) -> java.lang.CharSequence: ...
    def getStartUserSessionMessage(self, admin: android.content.ComponentName, /) -> java.lang.CharSequence: ...
    def getStorageEncryption(self, admin: android.content.ComponentName, /) -> bool: ...
    def getStorageEncryptionStatus(self) -> int: ...
    def getSubscriptionIds(self) -> java.util.Set[java.lang.Integer]: ...
    def getSystemUpdatePolicy(self) -> SystemUpdatePolicy | None: ...
    def getTransferOwnershipBundle(self) -> android.os.PersistableBundle | None: ...
    def getTrustAgentConfiguration(self, admin: android.content.ComponentName, agent: android.content.ComponentName, /) -> java.util.List[android.os.PersistableBundle] | None: ...
    def getUserControlDisabledPackages(self, admin: android.content.ComponentName, /) -> java.util.List[java.lang.String]: ...
    def getUserRestrictions(self, admin: android.content.ComponentName, /) -> android.os.Bundle: ...
    def getUserRestrictionsGlobally(self) -> android.os.Bundle: ...
    def getWifiMacAddress(self, admin: android.content.ComponentName, /) -> str | None: ...
    def getWifiSsidPolicy(self) -> WifiSsidPolicy | None: ...
    def grantKeyPairToApp(self, admin: android.content.ComponentName, alias: str | java.lang.String, packageName: str | java.lang.String, /) -> bool: ...
    def grantKeyPairToWifiAuth(self, alias: str | java.lang.String, /) -> bool: ...
    def hasCaCertInstalled(self, admin: android.content.ComponentName, certBuffer: java.chaquopy.JavaArrayJByte, /) -> bool: ...
    def hasGrantedPolicy(self, admin: android.content.ComponentName, usesPolicy: int | java.jint | java.lang.Integer, /) -> bool: ...
    def hasKeyPair(self, alias: str | java.lang.String, /) -> bool: ...
    def hasLockdownAdminConfiguredNetworks(self, admin: android.content.ComponentName, /) -> bool: ...
    def installCaCert(self, admin: android.content.ComponentName, certBuffer: java.chaquopy.JavaArrayJByte, /) -> bool: ...
    def installExistingPackage(self, admin: android.content.ComponentName, packageName: str | java.lang.String, /) -> bool: ...
    @typing.overload
    def installKeyPair(self, admin: android.content.ComponentName, privKey: java.security.PrivateKey, cert: java.security.cert.Certificate, alias: str | java.lang.String, /) -> bool: ...
    @typing.overload
    def installKeyPair(self, admin: android.content.ComponentName, privKey: java.security.PrivateKey, certs: java.chaquopy.JavaArray[java.security.cert.Certificate], alias: str | java.lang.String, flags: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    def installKeyPair(self, admin: android.content.ComponentName, privKey: java.security.PrivateKey, certs: java.chaquopy.JavaArray[java.security.cert.Certificate], alias: str | java.lang.String, requestAccess: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def installSystemUpdate(self, admin: android.content.ComponentName, updateFilePath: android.net.Uri, executor: java.util.concurrent.Executor, callback: DevicePolicyManager.InstallSystemUpdateCallback, /) -> None: ...
    def isActivePasswordSufficient(self) -> bool: ...
    def isActivePasswordSufficientForDeviceRequirement(self) -> bool: ...
    def isAdminActive(self, admin: android.content.ComponentName, /) -> bool: ...
    def isAffiliatedUser(self) -> bool: ...
    def isAlwaysOnVpnLockdownEnabled(self, admin: android.content.ComponentName, /) -> bool: ...
    def isApplicationHidden(self, admin: android.content.ComponentName, packageName: str | java.lang.String, /) -> bool: ...
    def isBackupServiceEnabled(self, admin: android.content.ComponentName, /) -> bool: ...
    def isCallerApplicationRestrictionsManagingPackage(self) -> bool: ...
    def isCommonCriteriaModeEnabled(self, admin: android.content.ComponentName, /) -> bool: ...
    def isComplianceAcknowledgementRequired(self) -> bool: ...
    def isDeviceFinanced(self) -> bool: ...
    def isDeviceIdAttestationSupported(self) -> bool: ...
    def isDeviceOwnerApp(self, packageName: str | java.lang.String, /) -> bool: ...
    def isEphemeralUser(self, admin: android.content.ComponentName, /) -> bool: ...
    def isKeyPairGrantedToWifiAuth(self, alias: str | java.lang.String, /) -> bool: ...
    def isLockTaskPermitted(self, pkg: str | java.lang.String, /) -> bool: ...
    def isLogoutEnabled(self) -> bool: ...
    def isManagedProfile(self, admin: android.content.ComponentName, /) -> bool: ...
    def isMasterVolumeMuted(self, admin: android.content.ComponentName, /) -> bool: ...
    @staticmethod
    def isMtePolicyEnforced() -> bool: ...
    def isNetworkLoggingEnabled(self, admin: android.content.ComponentName, /) -> bool: ...
    def isOrganizationOwnedDeviceWithManagedProfile(self) -> bool: ...
    def isOverrideApnEnabled(self, admin: android.content.ComponentName, /) -> bool: ...
    def isPackageSuspended(self, admin: android.content.ComponentName, packageName: str | java.lang.String, /) -> bool: ...
    def isPreferentialNetworkServiceEnabled(self) -> bool: ...
    def isProfileOwnerApp(self, packageName: str | java.lang.String, /) -> bool: ...
    def isProvisioningAllowed(self, action: str | java.lang.String, /) -> bool: ...
    def isResetPasswordTokenActive(self, admin: android.content.ComponentName, /) -> bool: ...
    def isSafeOperation(self, reason: int | java.jint | java.lang.Integer, /) -> bool: ...
    def isSecurityLoggingEnabled(self, admin: android.content.ComponentName, /) -> bool: ...
    def isStatusBarDisabled(self) -> bool: ...
    def isUninstallBlocked(self, admin: android.content.ComponentName, packageName: str | java.lang.String, /) -> bool: ...
    def isUniqueDeviceAttestationSupported(self) -> bool: ...
    def isUsbDataSignalingEnabled(self) -> bool: ...
    def isUsingUnifiedPassword(self, admin: android.content.ComponentName, /) -> bool: ...
    def listForegroundAffiliatedUsers(self) -> java.util.List[android.os.UserHandle]: ...
    @typing.overload
    def lockNow(self) -> None: ...
    @typing.overload
    def lockNow(self, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def logoutUser(self, admin: android.content.ComponentName, /) -> int: ...
    def reboot(self, admin: android.content.ComponentName, /) -> None: ...
    def removeActiveAdmin(self, admin: android.content.ComponentName, /) -> None: ...
    def removeCrossProfileWidgetProvider(self, admin: android.content.ComponentName, packageName: str | java.lang.String, /) -> bool: ...
    def removeKeyPair(self, admin: android.content.ComponentName, alias: str | java.lang.String, /) -> bool: ...
    def removeOverrideApn(self, admin: android.content.ComponentName, apnId: int | java.jint | java.lang.Integer, /) -> bool: ...
    def removeUser(self, admin: android.content.ComponentName, userHandle: android.os.UserHandle, /) -> bool: ...
    def requestBugreport(self, admin: android.content.ComponentName, /) -> bool: ...
    def resetPassword(self, password: str | java.lang.String, flags: int | java.jint | java.lang.Integer, /) -> bool: ...
    def resetPasswordWithToken(self, admin: android.content.ComponentName, password: str | java.lang.String, token: java.chaquopy.JavaArrayJByte, flags: int | java.jint | java.lang.Integer, /) -> bool: ...
    def retrieveNetworkLogs(self, admin: android.content.ComponentName, batchToken: int | java.jlong | java.lang.Long, /) -> java.util.List[NetworkEvent] | None: ...
    def retrievePreRebootSecurityLogs(self, admin: android.content.ComponentName, /) -> java.util.List[SecurityLog.SecurityEvent] | None: ...
    def retrieveSecurityLogs(self, admin: android.content.ComponentName, /) -> java.util.List[SecurityLog.SecurityEvent] | None: ...
    def revokeKeyPairFromApp(self, admin: android.content.ComponentName, alias: str | java.lang.String, packageName: str | java.lang.String, /) -> bool: ...
    def revokeKeyPairFromWifiAuth(self, alias: str | java.lang.String, /) -> bool: ...
    def setAccountManagementDisabled(self, admin: android.content.ComponentName, accountType: str | java.lang.String, disabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setAffiliationIds(self, admin: android.content.ComponentName, ids: java.util.Set[java.lang.String], /) -> None: ...
    @typing.overload
    def setAlwaysOnVpnPackage(self, admin: android.content.ComponentName, vpnPackage: str | java.lang.String, lockdownEnabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def setAlwaysOnVpnPackage(self, admin: android.content.ComponentName, vpnPackage: str | java.lang.String, lockdownEnabled: bool | java.jboolean | java.lang.Boolean, lockdownAllowlist: java.util.Set[java.lang.String], /) -> None: ...
    def setAppFunctionsPolicy(self, policy: int | java.jint | java.lang.Integer, /) -> None: ...
    def setApplicationHidden(self, admin: android.content.ComponentName, packageName: str | java.lang.String, hidden: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def setApplicationRestrictions(self, admin: android.content.ComponentName, packageName: str | java.lang.String, settings: android.os.Bundle, /) -> None: ...
    def setApplicationRestrictionsManagingPackage(self, admin: android.content.ComponentName, packageName: str | java.lang.String, /) -> None: ...
    def setAutoTimeEnabled(self, admin: android.content.ComponentName, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setAutoTimePolicy(self, policy: int | java.jint | java.lang.Integer, /) -> None: ...
    def setAutoTimeRequired(self, admin: android.content.ComponentName, required: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setAutoTimeZoneEnabled(self, admin: android.content.ComponentName, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setAutoTimeZonePolicy(self, policy: int | java.jint | java.lang.Integer, /) -> None: ...
    def setBackupServiceEnabled(self, admin: android.content.ComponentName, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setBluetoothContactSharingDisabled(self, admin: android.content.ComponentName, disabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setCameraDisabled(self, admin: android.content.ComponentName, disabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setCertInstallerPackage(self, admin: android.content.ComponentName, installerPackage: str | java.lang.String, /) -> None: ...
    def setCommonCriteriaModeEnabled(self, admin: android.content.ComponentName, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setConfiguredNetworksLockdownState(self, admin: android.content.ComponentName, lockdown: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setContentProtectionPolicy(self, admin: android.content.ComponentName, policy: int | java.jint | java.lang.Integer, /) -> None: ...
    def setCredentialManagerPolicy(self, policy: PackagePolicy, /) -> None: ...
    def setCrossProfileCalendarPackages(self, admin: android.content.ComponentName, packageNames: java.util.Set[java.lang.String], /) -> None: ...
    def setCrossProfileCallerIdDisabled(self, admin: android.content.ComponentName, disabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setCrossProfileContactsSearchDisabled(self, admin: android.content.ComponentName, disabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setCrossProfilePackages(self, admin: android.content.ComponentName, packageNames: java.util.Set[java.lang.String], /) -> None: ...
    def setDefaultDialerApplication(self, packageName: str | java.lang.String, /) -> None: ...
    def setDefaultSmsApplication(self, admin: android.content.ComponentName, packageName: str | java.lang.String, /) -> None: ...
    def setDelegatedScopes(self, admin: android.content.ComponentName, delegatePackage: str | java.lang.String, scopes: java.util.List[java.lang.String], /) -> None: ...
    def setDeviceOwnerLockScreenInfo(self, admin: android.content.ComponentName, info: java.lang.CharSequence, /) -> None: ...
    def setEndUserSessionMessage(self, admin: android.content.ComponentName, endUserSessionMessage: java.lang.CharSequence, /) -> None: ...
    def setFactoryResetProtectionPolicy(self, admin: android.content.ComponentName, policy: FactoryResetProtectionPolicy, /) -> None: ...
    def setGlobalPrivateDnsModeOpportunistic(self, admin: android.content.ComponentName, /) -> int: ...
    def setGlobalPrivateDnsModeSpecifiedHost(self, admin: android.content.ComponentName, privateDnsHost: str | java.lang.String, /) -> int: ...
    def setGlobalSetting(self, admin: android.content.ComponentName, setting: str | java.lang.String, value: str | java.lang.String, /) -> None: ...
    def setKeepUninstalledPackages(self, admin: android.content.ComponentName, packageNames: java.util.List[java.lang.String], /) -> None: ...
    def setKeyPairCertificate(self, admin: android.content.ComponentName, alias: str | java.lang.String, certs: java.util.List[java.security.cert.Certificate], isUserSelectable: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def setKeyguardDisabled(self, admin: android.content.ComponentName, disabled: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def setKeyguardDisabledFeatures(self, admin: android.content.ComponentName, which: int | java.jint | java.lang.Integer, /) -> None: ...
    def setLocationEnabled(self, admin: android.content.ComponentName, locationEnabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setLockTaskFeatures(self, admin: android.content.ComponentName, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def setLockTaskPackages(self, admin: android.content.ComponentName, packages: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def setLogoutEnabled(self, admin: android.content.ComponentName, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setLongSupportMessage(self, admin: android.content.ComponentName, message: java.lang.CharSequence, /) -> None: ...
    def setManagedProfileCallerIdAccessPolicy(self, policy: PackagePolicy, /) -> None: ...
    def setManagedProfileContactsAccessPolicy(self, policy: PackagePolicy, /) -> None: ...
    def setManagedProfileMaximumTimeOff(self, admin: android.content.ComponentName, timeoutMillis: int | java.jlong | java.lang.Long, /) -> None: ...
    def setManagedSubscriptionsPolicy(self, policy: ManagedSubscriptionsPolicy, /) -> None: ...
    def setMasterVolumeMuted(self, admin: android.content.ComponentName, on: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setMaximumFailedPasswordsForWipe(self, admin: android.content.ComponentName, num: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMaximumTimeToLock(self, admin: android.content.ComponentName, timeMs: int | java.jlong | java.lang.Long, /) -> None: ...
    def setMeteredDataDisabledPackages(self, admin: android.content.ComponentName, packageNames: java.util.List[java.lang.String], /) -> java.util.List[java.lang.String]: ...
    def setMinimumRequiredWifiSecurityLevel(self, level: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMtePolicy(self, policy: int | java.jint | java.lang.Integer, /) -> None: ...
    def setNearbyAppStreamingPolicy(self, policy: int | java.jint | java.lang.Integer, /) -> None: ...
    def setNearbyNotificationStreamingPolicy(self, policy: int | java.jint | java.lang.Integer, /) -> None: ...
    def setNetworkLoggingEnabled(self, admin: android.content.ComponentName, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setOrganizationColor(self, admin: android.content.ComponentName, color: int | java.jint | java.lang.Integer, /) -> None: ...
    def setOrganizationId(self, enterpriseId: str | java.lang.String, /) -> None: ...
    def setOrganizationName(self, admin: android.content.ComponentName, title: java.lang.CharSequence, /) -> None: ...
    def setOverrideApnsEnabled(self, admin: android.content.ComponentName, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setPackagesSuspended(self, admin: android.content.ComponentName, packageNames: java.chaquopy.JavaArray[java.lang.String], suspended: bool | java.jboolean | java.lang.Boolean, /) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def setPasswordExpirationTimeout(self, admin: android.content.ComponentName, timeout: int | java.jlong | java.lang.Long, /) -> None: ...
    def setPasswordHistoryLength(self, admin: android.content.ComponentName, length: int | java.jint | java.lang.Integer, /) -> None: ...
    def setPasswordMinimumLength(self, admin: android.content.ComponentName, length: int | java.jint | java.lang.Integer, /) -> None: ...
    def setPasswordMinimumLetters(self, admin: android.content.ComponentName, length: int | java.jint | java.lang.Integer, /) -> None: ...
    def setPasswordMinimumLowerCase(self, admin: android.content.ComponentName, length: int | java.jint | java.lang.Integer, /) -> None: ...
    def setPasswordMinimumNonLetter(self, admin: android.content.ComponentName, length: int | java.jint | java.lang.Integer, /) -> None: ...
    def setPasswordMinimumNumeric(self, admin: android.content.ComponentName, length: int | java.jint | java.lang.Integer, /) -> None: ...
    def setPasswordMinimumSymbols(self, admin: android.content.ComponentName, length: int | java.jint | java.lang.Integer, /) -> None: ...
    def setPasswordMinimumUpperCase(self, admin: android.content.ComponentName, length: int | java.jint | java.lang.Integer, /) -> None: ...
    def setPasswordQuality(self, admin: android.content.ComponentName, quality: int | java.jint | java.lang.Integer, /) -> None: ...
    def setPermissionGrantState(self, admin: android.content.ComponentName, packageName: str | java.lang.String, permission: str | java.lang.String, grantState: int | java.jint | java.lang.Integer, /) -> bool: ...
    def setPermissionPolicy(self, admin: android.content.ComponentName, policy: int | java.jint | java.lang.Integer, /) -> None: ...
    def setPermittedAccessibilityServices(self, admin: android.content.ComponentName, packageNames: java.util.List[java.lang.String], /) -> bool: ...
    def setPermittedCrossProfileNotificationListeners(self, admin: android.content.ComponentName, packageList: java.util.List[java.lang.String], /) -> bool: ...
    def setPermittedInputMethods(self, admin: android.content.ComponentName, packageNames: java.util.List[java.lang.String], /) -> bool: ...
    def setPersonalAppsSuspended(self, admin: android.content.ComponentName, suspended: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setPreferentialNetworkServiceConfigs(self, preferentialNetworkServiceConfigs: java.util.List[PreferentialNetworkServiceConfig], /) -> None: ...
    def setPreferentialNetworkServiceEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setProfileEnabled(self, admin: android.content.ComponentName, /) -> None: ...
    def setProfileName(self, admin: android.content.ComponentName, profileName: str | java.lang.String, /) -> None: ...
    def setRecommendedGlobalProxy(self, admin: android.content.ComponentName, proxyInfo: android.net.ProxyInfo, /) -> None: ...
    def setRequiredPasswordComplexity(self, passwordComplexity: int | java.jint | java.lang.Integer, /) -> None: ...
    def setRequiredStrongAuthTimeout(self, admin: android.content.ComponentName, timeoutMs: int | java.jlong | java.lang.Long, /) -> None: ...
    def setResetPasswordToken(self, admin: android.content.ComponentName, token: java.chaquopy.JavaArrayJByte, /) -> bool: ...
    def setRestrictionsProvider(self, admin: android.content.ComponentName, provider: android.content.ComponentName, /) -> None: ...
    def setScreenCaptureDisabled(self, admin: android.content.ComponentName, disabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSecureSetting(self, admin: android.content.ComponentName, setting: str | java.lang.String, value: str | java.lang.String, /) -> None: ...
    def setSecurityLoggingEnabled(self, admin: android.content.ComponentName, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setShortSupportMessage(self, admin: android.content.ComponentName, message: java.lang.CharSequence, /) -> None: ...
    def setStartUserSessionMessage(self, admin: android.content.ComponentName, startUserSessionMessage: java.lang.CharSequence, /) -> None: ...
    def setStatusBarDisabled(self, admin: android.content.ComponentName, disabled: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def setStorageEncryption(self, admin: android.content.ComponentName, encrypt: bool | java.jboolean | java.lang.Boolean, /) -> int: ...
    def setSystemSetting(self, admin: android.content.ComponentName, setting: str | java.lang.String, value: str | java.lang.String, /) -> None: ...
    def setSystemUpdatePolicy(self, admin: android.content.ComponentName, policy: SystemUpdatePolicy, /) -> None: ...
    def setTime(self, admin: android.content.ComponentName, millis: int | java.jlong | java.lang.Long, /) -> bool: ...
    def setTimeZone(self, admin: android.content.ComponentName, timeZone: str | java.lang.String, /) -> bool: ...
    def setTrustAgentConfiguration(self, admin: android.content.ComponentName, target: android.content.ComponentName, configuration: android.os.PersistableBundle, /) -> None: ...
    def setUninstallBlocked(self, admin: android.content.ComponentName, packageName: str | java.lang.String, uninstallBlocked: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setUsbDataSignalingEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setUserControlDisabledPackages(self, admin: android.content.ComponentName, packages: java.util.List[java.lang.String], /) -> None: ...
    def setUserIcon(self, admin: android.content.ComponentName, icon: android.graphics.Bitmap, /) -> None: ...
    def setWifiSsidPolicy(self, policy: WifiSsidPolicy, /) -> None: ...
    def startUserInBackground(self, admin: android.content.ComponentName, userHandle: android.os.UserHandle, /) -> int: ...
    def stopUser(self, admin: android.content.ComponentName, userHandle: android.os.UserHandle, /) -> int: ...
    def switchUser(self, admin: android.content.ComponentName, userHandle: android.os.UserHandle, /) -> bool: ...
    def transferOwnership(self, admin: android.content.ComponentName, target: android.content.ComponentName, bundle: android.os.PersistableBundle, /) -> None: ...
    def uninstallAllUserCaCerts(self, admin: android.content.ComponentName, /) -> None: ...
    def uninstallCaCert(self, admin: android.content.ComponentName, certBuffer: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def updateOverrideApn(self, admin: android.content.ComponentName, apnId: int | java.jint | java.lang.Integer, apnSetting: android.telephony.data.ApnSetting, /) -> bool: ...
    @typing.overload
    def wipeData(self, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def wipeData(self, flags: int | java.jint | java.lang.Integer, reason: java.lang.CharSequence, /) -> None: ...
    def wipeDevice(self, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class OnClearApplicationUserDataListener(java.lang.Object):
        def onApplicationUserDataCleared(self, arg1: str | java.lang.String, arg2: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

    class InstallSystemUpdateCallback(java.lang.Object):
        UPDATE_ERROR_BATTERY_LOW: typing.ClassVar[int] = ...
        UPDATE_ERROR_FILE_NOT_FOUND: typing.ClassVar[int] = ...
        UPDATE_ERROR_INCORRECT_OS_VERSION: typing.ClassVar[int] = ...
        UPDATE_ERROR_UNKNOWN: typing.ClassVar[int] = ...
        UPDATE_ERROR_UPDATE_FILE_INVALID: typing.ClassVar[int] = ...
        def __init__(self) -> None: ...
        def onInstallUpdateError(self, errorCode: int | java.jint | java.lang.Integer, errorMessage: str | java.lang.String, /) -> None: ...

class DevicePolicyResources(java.lang.Object):
    UNDEFINED: typing.ClassVar[str] = ...

class DevicePolicyResourcesManager(java.lang.Object):
    @typing.overload
    def getDrawable(self, drawableId: str | java.lang.String, drawableStyle: str | java.lang.String, defaultDrawableLoader: java.util.function.Supplier[android.graphics.drawable.Drawable], /) -> android.graphics.drawable.Drawable | None: ...
    @typing.overload
    def getDrawable(self, drawableId: str | java.lang.String, drawableStyle: str | java.lang.String, drawableSource: str | java.lang.String, defaultDrawableLoader: java.util.function.Supplier[android.graphics.drawable.Drawable], /) -> android.graphics.drawable.Drawable | None: ...
    @typing.overload
    def getDrawableAsIcon(self, drawableId: str | java.lang.String, drawableStyle: str | java.lang.String, defaultIcon: android.graphics.drawable.Icon, /) -> android.graphics.drawable.Icon | None: ...
    @typing.overload
    def getDrawableAsIcon(self, drawableId: str | java.lang.String, drawableStyle: str | java.lang.String, drawableSource: str | java.lang.String, defaultIcon: android.graphics.drawable.Icon, /) -> android.graphics.drawable.Icon | None: ...
    @typing.overload
    def getDrawableForDensity(self, drawableId: str | java.lang.String, drawableStyle: str | java.lang.String, density: int | java.jint | java.lang.Integer, defaultDrawableLoader: java.util.function.Supplier[android.graphics.drawable.Drawable], /) -> android.graphics.drawable.Drawable | None: ...
    @typing.overload
    def getDrawableForDensity(self, drawableId: str | java.lang.String, drawableStyle: str | java.lang.String, drawableSource: str | java.lang.String, density: int | java.jint | java.lang.Integer, defaultDrawableLoader: java.util.function.Supplier[android.graphics.drawable.Drawable], /) -> android.graphics.drawable.Drawable | None: ...
    @typing.overload
    def getString(self, stringId: str | java.lang.String, defaultStringLoader: java.util.function.Supplier[java.lang.String], /) -> str | None: ...
    @typing.overload
    def getString(self, stringId: str | java.lang.String, defaultStringLoader: java.util.function.Supplier[java.lang.String], /, *formatArgs: java.lang.Object) -> str | None: ...

class DnsEvent(NetworkEvent, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[DnsEvent]] = ...
    def describeContents(self) -> int: ...
    def getHostname(self) -> str: ...
    def getInetAddresses(self) -> java.util.List[java.net.InetAddress]: ...
    def getTotalResolvedAddressCount(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class FactoryResetProtectionPolicy(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[FactoryResetProtectionPolicy]] = ...
    def describeContents(self) -> int: ...
    def getFactoryResetProtectionAccounts(self) -> java.util.List[java.lang.String]: ...
    def isFactoryResetProtectionEnabled(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> FactoryResetProtectionPolicy: ...
        def setFactoryResetProtectionAccounts(self, factoryResetProtectionAccounts: java.util.List[java.lang.String], /) -> FactoryResetProtectionPolicy.Builder: ...
        def setFactoryResetProtectionEnabled(self, factoryResetProtectionEnabled: bool | java.jboolean | java.lang.Boolean, /) -> FactoryResetProtectionPolicy.Builder: ...

class FreezePeriod(java.lang.Object):
    def __init__(self, start: java.time.MonthDay, end: java.time.MonthDay, /) -> None: ...
    def getEnd(self) -> java.time.MonthDay: ...
    def getStart(self) -> java.time.MonthDay: ...
    def toString(self) -> str: ...

class ManagedSubscriptionsPolicy(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ManagedSubscriptionsPolicy]] = ...
    TYPE_ALL_MANAGED_SUBSCRIPTIONS: typing.ClassVar[int] = ...
    TYPE_ALL_PERSONAL_SUBSCRIPTIONS: typing.ClassVar[int] = ...
    def __init__(self, policyType: int | java.jint | java.lang.Integer, /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, thatObject: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getPolicyType(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class NetworkEvent(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[NetworkEvent]] = ...
    def describeContents(self) -> int: ...
    def getId(self) -> int: ...
    def getPackageName(self) -> str: ...
    def getTimestamp(self) -> int: ...
    def writeToParcel(self, arg1: android.os.Parcel, arg2: int | java.jint | java.lang.Integer, /) -> None: ...

class PackagePolicy(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PackagePolicy]] = ...
    PACKAGE_POLICY_ALLOWLIST: typing.ClassVar[int] = ...
    PACKAGE_POLICY_ALLOWLIST_AND_SYSTEM: typing.ClassVar[int] = ...
    PACKAGE_POLICY_BLOCKLIST: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, policyType: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, policyType: int | java.jint | java.lang.Integer, packageNames: java.util.Set[java.lang.String], /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, thatObject: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getPackageNames(self) -> java.util.Set[java.lang.String]: ...
    def getPolicyType(self) -> int: ...
    def hashCode(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class PolicyUpdateReceiver(android.content.BroadcastReceiver):
    ACTION_DEVICE_POLICY_CHANGED: typing.ClassVar[str] = ...
    ACTION_DEVICE_POLICY_SET_RESULT: typing.ClassVar[str] = ...
    EXTRA_ACCOUNT_TYPE: typing.ClassVar[str] = ...
    EXTRA_INTENT_FILTER: typing.ClassVar[str] = ...
    EXTRA_PACKAGE_NAME: typing.ClassVar[str] = ...
    EXTRA_PERMISSION_NAME: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    def onPolicyChanged(self, context: android.content.Context, policyIdentifier: str | java.lang.String, additionalPolicyParams: android.os.Bundle, targetUser: TargetUser, policyUpdateResult: PolicyUpdateResult, /) -> None: ...
    def onPolicySetResult(self, context: android.content.Context, policyIdentifier: str | java.lang.String, additionalPolicyParams: android.os.Bundle, targetUser: TargetUser, policyUpdateResult: PolicyUpdateResult, /) -> None: ...
    def onReceive(self, context: android.content.Context, intent: android.content.Intent, /) -> None: ...

class PolicyUpdateResult(java.lang.Object):
    RESULT_FAILURE_CONFLICTING_ADMIN_POLICY: typing.ClassVar[int] = ...
    RESULT_FAILURE_HARDWARE_LIMITATION: typing.ClassVar[int] = ...
    RESULT_FAILURE_STORAGE_LIMIT_REACHED: typing.ClassVar[int] = ...
    RESULT_FAILURE_UNKNOWN: typing.ClassVar[int] = ...
    RESULT_POLICY_CLEARED: typing.ClassVar[int] = ...
    RESULT_POLICY_SET: typing.ClassVar[int] = ...
    def __init__(self, resultCode: int | java.jint | java.lang.Integer, /) -> None: ...
    def getResultCode(self) -> int: ...

class PreferentialNetworkServiceConfig(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PreferentialNetworkServiceConfig]] = ...
    PREFERENTIAL_NETWORK_ID_1: typing.ClassVar[int] = ...
    PREFERENTIAL_NETWORK_ID_2: typing.ClassVar[int] = ...
    PREFERENTIAL_NETWORK_ID_3: typing.ClassVar[int] = ...
    PREFERENTIAL_NETWORK_ID_4: typing.ClassVar[int] = ...
    PREFERENTIAL_NETWORK_ID_5: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getExcludedUids(self) -> java.chaquopy.JavaArrayJInt: ...
    def getIncludedUids(self) -> java.chaquopy.JavaArrayJInt: ...
    def getNetworkId(self) -> int: ...
    def hashCode(self) -> int: ...
    def isEnabled(self) -> bool: ...
    def isFallbackToDefaultConnectionAllowed(self) -> bool: ...
    def shouldBlockNonMatchingNetworks(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> PreferentialNetworkServiceConfig: ...
        def setEnabled(self, isEnabled: bool | java.jboolean | java.lang.Boolean, /) -> PreferentialNetworkServiceConfig.Builder: ...
        def setExcludedUids(self, uids: java.chaquopy.JavaArrayJInt, /) -> PreferentialNetworkServiceConfig.Builder: ...
        def setFallbackToDefaultConnectionAllowed(self, allowFallbackToDefaultConnection: bool | java.jboolean | java.lang.Boolean, /) -> PreferentialNetworkServiceConfig.Builder: ...
        def setIncludedUids(self, uids: java.chaquopy.JavaArrayJInt, /) -> PreferentialNetworkServiceConfig.Builder: ...
        def setNetworkId(self, preferenceId: int | java.jint | java.lang.Integer, /) -> PreferentialNetworkServiceConfig.Builder: ...
        def setShouldBlockNonMatchingNetworks(self, blockNonMatchingNetworks: bool | java.jboolean | java.lang.Boolean, /) -> PreferentialNetworkServiceConfig.Builder: ...

class SecurityLog(java.lang.Object):
    LEVEL_ERROR: typing.ClassVar[int] = ...
    LEVEL_INFO: typing.ClassVar[int] = ...
    LEVEL_WARNING: typing.ClassVar[int] = ...
    TAG_ADB_SHELL_CMD: typing.ClassVar[int] = ...
    TAG_ADB_SHELL_INTERACTIVE: typing.ClassVar[int] = ...
    TAG_APP_PROCESS_START: typing.ClassVar[int] = ...
    TAG_BACKUP_SERVICE_TOGGLED: typing.ClassVar[int] = ...
    TAG_BLUETOOTH_CONNECTION: typing.ClassVar[int] = ...
    TAG_BLUETOOTH_DISCONNECTION: typing.ClassVar[int] = ...
    TAG_CAMERA_POLICY_SET: typing.ClassVar[int] = ...
    TAG_CERT_AUTHORITY_INSTALLED: typing.ClassVar[int] = ...
    TAG_CERT_AUTHORITY_REMOVED: typing.ClassVar[int] = ...
    TAG_CERT_VALIDATION_FAILURE: typing.ClassVar[int] = ...
    TAG_CRYPTO_SELF_TEST_COMPLETED: typing.ClassVar[int] = ...
    TAG_KEYGUARD_DISABLED_FEATURES_SET: typing.ClassVar[int] = ...
    TAG_KEYGUARD_DISMISSED: typing.ClassVar[int] = ...
    TAG_KEYGUARD_DISMISS_AUTH_ATTEMPT: typing.ClassVar[int] = ...
    TAG_KEYGUARD_SECURED: typing.ClassVar[int] = ...
    TAG_KEY_DESTRUCTION: typing.ClassVar[int] = ...
    TAG_KEY_GENERATED: typing.ClassVar[int] = ...
    TAG_KEY_IMPORT: typing.ClassVar[int] = ...
    TAG_KEY_INTEGRITY_VIOLATION: typing.ClassVar[int] = ...
    TAG_LOGGING_STARTED: typing.ClassVar[int] = ...
    TAG_LOGGING_STOPPED: typing.ClassVar[int] = ...
    TAG_LOG_BUFFER_SIZE_CRITICAL: typing.ClassVar[int] = ...
    TAG_MAX_PASSWORD_ATTEMPTS_SET: typing.ClassVar[int] = ...
    TAG_MAX_SCREEN_LOCK_TIMEOUT_SET: typing.ClassVar[int] = ...
    TAG_MEDIA_MOUNT: typing.ClassVar[int] = ...
    TAG_MEDIA_UNMOUNT: typing.ClassVar[int] = ...
    TAG_NFC_DISABLED: typing.ClassVar[int] = ...
    TAG_NFC_ENABLED: typing.ClassVar[int] = ...
    TAG_OS_SHUTDOWN: typing.ClassVar[int] = ...
    TAG_OS_STARTUP: typing.ClassVar[int] = ...
    TAG_PACKAGE_INSTALLED: typing.ClassVar[int] = ...
    TAG_PACKAGE_UNINSTALLED: typing.ClassVar[int] = ...
    TAG_PACKAGE_UPDATED: typing.ClassVar[int] = ...
    TAG_PASSWORD_CHANGED: typing.ClassVar[int] = ...
    TAG_PASSWORD_COMPLEXITY_REQUIRED: typing.ClassVar[int] = ...
    TAG_PASSWORD_COMPLEXITY_SET: typing.ClassVar[int] = ...
    TAG_PASSWORD_EXPIRATION_SET: typing.ClassVar[int] = ...
    TAG_PASSWORD_HISTORY_LENGTH_SET: typing.ClassVar[int] = ...
    TAG_REMOTE_LOCK: typing.ClassVar[int] = ...
    TAG_SYNC_RECV_FILE: typing.ClassVar[int] = ...
    TAG_SYNC_SEND_FILE: typing.ClassVar[int] = ...
    TAG_USER_RESTRICTION_ADDED: typing.ClassVar[int] = ...
    TAG_USER_RESTRICTION_REMOVED: typing.ClassVar[int] = ...
    TAG_WIFI_CONNECTION: typing.ClassVar[int] = ...
    TAG_WIFI_DISCONNECTION: typing.ClassVar[int] = ...
    TAG_WIPE_FAILURE: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...

    class SecurityEvent(android.os.Parcelable):
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SecurityLog.SecurityEvent]] = ...
        def describeContents(self) -> int: ...
        def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def getData(self) -> java.lang.Object: ...
        def getId(self) -> int: ...
        def getLogLevel(self) -> int: ...
        def getTag(self) -> int: ...
        def getTimeNanos(self) -> int: ...
        def hashCode(self) -> int: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class SystemUpdateInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SystemUpdateInfo]] = ...
    SECURITY_PATCH_STATE_FALSE: typing.ClassVar[int] = ...
    SECURITY_PATCH_STATE_TRUE: typing.ClassVar[int] = ...
    SECURITY_PATCH_STATE_UNKNOWN: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getReceivedTime(self) -> int: ...
    def getSecurityPatchState(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class SystemUpdatePolicy(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SystemUpdatePolicy]] = ...
    TYPE_INSTALL_AUTOMATIC: typing.ClassVar[int] = ...
    TYPE_INSTALL_WINDOWED: typing.ClassVar[int] = ...
    TYPE_POSTPONE: typing.ClassVar[int] = ...
    @staticmethod
    def createAutomaticInstallPolicy() -> SystemUpdatePolicy: ...
    @staticmethod
    def createPostponeInstallPolicy() -> SystemUpdatePolicy: ...
    @staticmethod
    def createWindowedInstallPolicy(startTime: int | java.jint | java.lang.Integer, endTime: int | java.jint | java.lang.Integer, /) -> SystemUpdatePolicy: ...
    def describeContents(self) -> int: ...
    def getFreezePeriods(self) -> java.util.List[FreezePeriod]: ...
    def getInstallWindowEnd(self) -> int: ...
    def getInstallWindowStart(self) -> int: ...
    def getPolicyType(self) -> int: ...
    def setFreezePeriods(self, freezePeriods: java.util.List[FreezePeriod], /) -> SystemUpdatePolicy: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class ValidationFailedException(android.os.Parcelable, java.lang.IllegalArgumentException):
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SystemUpdatePolicy.ValidationFailedException]] = ...
        ERROR_COMBINED_FREEZE_PERIOD_TOO_CLOSE: typing.ClassVar[int] = ...
        ERROR_COMBINED_FREEZE_PERIOD_TOO_LONG: typing.ClassVar[int] = ...
        ERROR_DUPLICATE_OR_OVERLAP: typing.ClassVar[int] = ...
        ERROR_NEW_FREEZE_PERIOD_TOO_CLOSE: typing.ClassVar[int] = ...
        ERROR_NEW_FREEZE_PERIOD_TOO_LONG: typing.ClassVar[int] = ...
        ERROR_UNKNOWN: typing.ClassVar[int] = ...
        def describeContents(self) -> int: ...
        def getErrorCode(self) -> int: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class TargetUser(java.lang.Object):
    GLOBAL: typing.ClassVar[TargetUser] = ...
    LOCAL_USER: typing.ClassVar[TargetUser] = ...
    PARENT_USER: typing.ClassVar[TargetUser] = ...
    UNKNOWN_USER: typing.ClassVar[TargetUser] = ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def hashCode(self) -> int: ...

class UnsafeStateException(android.os.Parcelable, java.lang.IllegalStateException):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[UnsafeStateException]] = ...
    def describeContents(self) -> int: ...
    def getMessage(self) -> str: ...
    def getReasons(self) -> java.util.List[java.lang.Integer]: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class WifiSsidPolicy(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[WifiSsidPolicy]] = ...
    WIFI_SSID_POLICY_TYPE_ALLOWLIST: typing.ClassVar[int] = ...
    WIFI_SSID_POLICY_TYPE_DENYLIST: typing.ClassVar[int] = ...
    def __init__(self, policyType: int | java.jint | java.lang.Integer, ssids: java.util.Set[android.net.wifi.WifiSsid], /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, thatObject: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getPolicyType(self) -> int: ...
    def getSsids(self) -> java.util.Set[android.net.wifi.WifiSsid]: ...
    def hashCode(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...



import typing

import java
import java.chaquopy
import java.lang
import java.net
import java.security
import java.security.cert
import javax.net.ssl
import org.apache.http.conn.scheme
import org.apache.http.params

class AbstractVerifier(X509HostnameVerifier):
    def __init__(self) -> None: ...
    @staticmethod
    def acceptableCountryWildcard(cn: str | java.lang.String, /) -> bool: ...
    @staticmethod
    def countDots(s: str | java.lang.String, /) -> int: ...
    @staticmethod
    def getCNs(cert: java.security.cert.X509Certificate, /) -> java.chaquopy.JavaArray[java.lang.String]: ...
    @staticmethod
    def getDNSSubjectAlts(cert: java.security.cert.X509Certificate, /) -> java.chaquopy.JavaArray[java.lang.String]: ...
    @typing.overload
    def verify(self, host: str | java.lang.String, cert: java.security.cert.X509Certificate, /) -> None: ...
    @typing.overload
    def verify(self, host: str | java.lang.String, session: javax.net.ssl.SSLSession, /) -> bool: ...
    @typing.overload
    def verify(self, host: str | java.lang.String, ssl: javax.net.ssl.SSLSocket, /) -> None: ...
    @typing.overload
    def verify(self, host: str | java.lang.String, cns: java.chaquopy.JavaArray[java.lang.String], subjectAlts: java.chaquopy.JavaArray[java.lang.String], strictWithSubDomains: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

class AllowAllHostnameVerifier(AbstractVerifier):
    def __init__(self) -> None: ...
    def toString(self) -> str: ...
    def verify(self, host: str | java.lang.String, cns: java.chaquopy.JavaArray[java.lang.String], subjectAlts: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...

class BrowserCompatHostnameVerifier(AbstractVerifier):
    def __init__(self) -> None: ...
    def toString(self) -> str: ...
    def verify(self, host: str | java.lang.String, cns: java.chaquopy.JavaArray[java.lang.String], subjectAlts: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...

class SSLSocketFactory(org.apache.http.conn.scheme.LayeredSocketFactory):
    ALLOW_ALL_HOSTNAME_VERIFIER: typing.ClassVar[X509HostnameVerifier] = ...
    BROWSER_COMPATIBLE_HOSTNAME_VERIFIER: typing.ClassVar[X509HostnameVerifier] = ...
    SSL: typing.ClassVar[str] = ...
    SSLV2: typing.ClassVar[str] = ...
    STRICT_HOSTNAME_VERIFIER: typing.ClassVar[X509HostnameVerifier] = ...
    TLS: typing.ClassVar[str] = ...
    @typing.overload
    def __init__(self, truststore: java.security.KeyStore, /) -> None: ...
    @typing.overload
    def __init__(self, keystore: java.security.KeyStore, keystorePassword: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, keystore: java.security.KeyStore, keystorePassword: str | java.lang.String, truststore: java.security.KeyStore, /) -> None: ...
    @typing.overload
    def __init__(self, algorithm: str | java.lang.String, keystore: java.security.KeyStore, keystorePassword: str | java.lang.String, truststore: java.security.KeyStore, random: java.security.SecureRandom, nameResolver: org.apache.http.conn.scheme.HostNameResolver, /) -> None: ...
    def connectSocket(self, sock: java.net.Socket, host: str | java.lang.String, port: int | java.jint | java.lang.Integer, localAddress: java.net.InetAddress, localPort: int | java.jint | java.lang.Integer, params: org.apache.http.params.HttpParams, /) -> java.net.Socket: ...
    @typing.overload
    def createSocket(self) -> java.net.Socket: ...
    @typing.overload
    def createSocket(self, socket: java.net.Socket, host: str | java.lang.String, port: int | java.jint | java.lang.Integer, autoClose: bool | java.jboolean | java.lang.Boolean, /) -> java.net.Socket: ...
    def getHostnameVerifier(self) -> X509HostnameVerifier: ...
    @staticmethod
    def getSocketFactory() -> SSLSocketFactory: ...
    def isSecure(self, sock: java.net.Socket, /) -> bool: ...
    def setHostnameVerifier(self, hostnameVerifier: X509HostnameVerifier, /) -> None: ...

class StrictHostnameVerifier(AbstractVerifier):
    def __init__(self) -> None: ...
    def toString(self) -> str: ...
    def verify(self, host: str | java.lang.String, cns: java.chaquopy.JavaArray[java.lang.String], subjectAlts: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...

class X509HostnameVerifier(javax.net.ssl.HostnameVerifier):
    @typing.overload
    def verify(self, arg1: str | java.lang.String, arg2: java.security.cert.X509Certificate, /) -> None: ...
    @typing.overload
    def verify(self, arg1: str | java.lang.String, arg2: javax.net.ssl.SSLSession, /) -> bool: ...
    @typing.overload
    def verify(self, arg1: str | java.lang.String, arg2: javax.net.ssl.SSLSocket, /) -> None: ...
    @typing.overload
    def verify(self, arg1: str | java.lang.String, arg2: java.chaquopy.JavaArray[java.lang.String], arg3: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...



import typing

import android.app
import android.content
import android.media
import android.net
import android.os
import java
import java.chaquopy
import java.io
import java.lang
import java.util

class SynthesisCallback(java.lang.Object):
    def audioAvailable(self, arg1: java.chaquopy.JavaArrayJByte, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> int: ...
    def done(self) -> int: ...
    @typing.overload
    def error(self) -> None: ...
    @typing.overload
    def error(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def getMaxBufferSize(self) -> int: ...
    def hasFinished(self) -> bool: ...
    def hasStarted(self) -> bool: ...
    def rangeStart(self, markerInFrames: int | java.jint | java.lang.Integer, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> None: ...
    def start(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> int: ...

class SynthesisRequest(java.lang.Object):
    @typing.overload
    def __init__(self, text: java.lang.CharSequence, params: android.os.Bundle, /) -> None: ...
    @typing.overload
    def __init__(self, text: str | java.lang.String, params: android.os.Bundle, /) -> None: ...
    def getCallerUid(self) -> int: ...
    def getCharSequenceText(self) -> java.lang.CharSequence: ...
    def getCountry(self) -> str: ...
    def getLanguage(self) -> str: ...
    def getParams(self) -> android.os.Bundle: ...
    def getPitch(self) -> int: ...
    def getSpeechRate(self) -> int: ...
    def getText(self) -> str: ...
    def getVariant(self) -> str: ...
    def getVoiceName(self) -> str: ...

class TextToSpeech(java.lang.Object):
    ACTION_TTS_QUEUE_PROCESSING_COMPLETED: typing.ClassVar[str] = ...
    ERROR: typing.ClassVar[int] = ...
    ERROR_INVALID_REQUEST: typing.ClassVar[int] = ...
    ERROR_NETWORK: typing.ClassVar[int] = ...
    ERROR_NETWORK_TIMEOUT: typing.ClassVar[int] = ...
    ERROR_NOT_INSTALLED_YET: typing.ClassVar[int] = ...
    ERROR_OUTPUT: typing.ClassVar[int] = ...
    ERROR_SERVICE: typing.ClassVar[int] = ...
    ERROR_SYNTHESIS: typing.ClassVar[int] = ...
    LANG_AVAILABLE: typing.ClassVar[int] = ...
    LANG_COUNTRY_AVAILABLE: typing.ClassVar[int] = ...
    LANG_COUNTRY_VAR_AVAILABLE: typing.ClassVar[int] = ...
    LANG_MISSING_DATA: typing.ClassVar[int] = ...
    LANG_NOT_SUPPORTED: typing.ClassVar[int] = ...
    QUEUE_ADD: typing.ClassVar[int] = ...
    QUEUE_FLUSH: typing.ClassVar[int] = ...
    STOPPED: typing.ClassVar[int] = ...
    SUCCESS: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, context: android.content.Context, listener: TextToSpeech.OnInitListener, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, listener: TextToSpeech.OnInitListener, engine: str | java.lang.String, /) -> None: ...
    @typing.overload
    def addEarcon(self, earcon: str | java.lang.String, uri: android.net.Uri, /) -> int: ...
    @typing.overload
    def addEarcon(self, earcon: str | java.lang.String, file: java.io.File, /) -> int: ...
    @typing.overload
    def addEarcon(self, earcon: str | java.lang.String, filename: str | java.lang.String, /) -> int: ...
    @typing.overload
    def addEarcon(self, earcon: str | java.lang.String, packagename: str | java.lang.String, resourceId: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def addSpeech(self, text: java.lang.CharSequence, uri: android.net.Uri, /) -> int: ...
    @typing.overload
    def addSpeech(self, text: java.lang.CharSequence, file: java.io.File, /) -> int: ...
    @typing.overload
    def addSpeech(self, text: str | java.lang.String, filename: str | java.lang.String, /) -> int: ...
    @typing.overload
    def addSpeech(self, text: java.lang.CharSequence, packagename: str | java.lang.String, resourceId: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def addSpeech(self, text: str | java.lang.String, packagename: str | java.lang.String, resourceId: int | java.jint | java.lang.Integer, /) -> int: ...
    def areDefaultsEnforced(self) -> bool: ...
    def getAvailableLanguages(self) -> java.util.Set[java.util.Locale]: ...
    def getDefaultEngine(self) -> str: ...
    def getDefaultLanguage(self) -> java.util.Locale: ...
    def getDefaultVoice(self) -> Voice: ...
    def getEngines(self) -> java.util.List[TextToSpeech.EngineInfo]: ...
    def getFeatures(self, locale: java.util.Locale, /) -> java.util.Set[java.lang.String]: ...
    def getLanguage(self) -> java.util.Locale: ...
    @staticmethod
    def getMaxSpeechInputLength() -> int: ...
    def getVoice(self) -> Voice: ...
    def getVoices(self) -> java.util.Set[Voice]: ...
    def isLanguageAvailable(self, loc: java.util.Locale, /) -> int: ...
    def isSpeaking(self) -> bool: ...
    @typing.overload
    def playEarcon(self, earcon: str | java.lang.String, queueMode: int | java.jint | java.lang.Integer, params: java.util.HashMap[java.lang.String, java.lang.String], /) -> int: ...
    @typing.overload
    def playEarcon(self, earcon: str | java.lang.String, queueMode: int | java.jint | java.lang.Integer, params: android.os.Bundle, utteranceId: str | java.lang.String, /) -> int: ...
    def playSilence(self, durationInMs: int | java.jlong | java.lang.Long, queueMode: int | java.jint | java.lang.Integer, params: java.util.HashMap[java.lang.String, java.lang.String], /) -> int: ...
    def playSilentUtterance(self, durationInMs: int | java.jlong | java.lang.Long, queueMode: int | java.jint | java.lang.Integer, utteranceId: str | java.lang.String, /) -> int: ...
    def setAudioAttributes(self, audioAttributes: android.media.AudioAttributes, /) -> int: ...
    def setEngineByPackageName(self, enginePackageName: str | java.lang.String, /) -> int: ...
    def setLanguage(self, loc: java.util.Locale, /) -> int: ...
    def setOnUtteranceCompletedListener(self, listener: TextToSpeech.OnUtteranceCompletedListener, /) -> int: ...
    def setOnUtteranceProgressListener(self, listener: UtteranceProgressListener, /) -> int: ...
    def setPitch(self, pitch: float | java.jfloat | java.lang.Float, /) -> int: ...
    def setSpeechRate(self, speechRate: float | java.jfloat | java.lang.Float, /) -> int: ...
    def setVoice(self, voice: Voice, /) -> int: ...
    def shutdown(self) -> None: ...
    @typing.overload
    def speak(self, text: str | java.lang.String, queueMode: int | java.jint | java.lang.Integer, params: java.util.HashMap[java.lang.String, java.lang.String], /) -> int: ...
    @typing.overload
    def speak(self, text: java.lang.CharSequence, queueMode: int | java.jint | java.lang.Integer, params: android.os.Bundle, utteranceId: str | java.lang.String, /) -> int: ...
    def stop(self) -> int: ...
    @typing.overload
    def synthesizeToFile(self, text: str | java.lang.String, params: java.util.HashMap[java.lang.String, java.lang.String], filename: str | java.lang.String, /) -> int: ...
    @typing.overload
    def synthesizeToFile(self, text: java.lang.CharSequence, params: android.os.Bundle, fileDescriptor: android.os.ParcelFileDescriptor, utteranceId: str | java.lang.String, /) -> int: ...
    @typing.overload
    def synthesizeToFile(self, text: java.lang.CharSequence, params: android.os.Bundle, file: java.io.File, utteranceId: str | java.lang.String, /) -> int: ...

    class OnUtteranceCompletedListener(java.lang.Object):
        def onUtteranceCompleted(self, arg1: str | java.lang.String, /) -> None: ...

    class OnInitListener(java.lang.Object):
        def onInit(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...

    class EngineInfo(java.lang.Object):
        icon: int = ...
        label: str = ...
        name: str = ...
        def __init__(self) -> None: ...
        def toString(self) -> str: ...

    class Engine(java.lang.Object):
        ACTION_CHECK_TTS_DATA: typing.ClassVar[str] = ...
        ACTION_GET_SAMPLE_TEXT: typing.ClassVar[str] = ...
        ACTION_INSTALL_TTS_DATA: typing.ClassVar[str] = ...
        ACTION_TTS_DATA_INSTALLED: typing.ClassVar[str] = ...
        CHECK_VOICE_DATA_BAD_DATA: typing.ClassVar[int] = ...
        CHECK_VOICE_DATA_FAIL: typing.ClassVar[int] = ...
        CHECK_VOICE_DATA_MISSING_DATA: typing.ClassVar[int] = ...
        CHECK_VOICE_DATA_MISSING_VOLUME: typing.ClassVar[int] = ...
        CHECK_VOICE_DATA_PASS: typing.ClassVar[int] = ...
        DEFAULT_STREAM: typing.ClassVar[int] = ...
        EXTRA_AVAILABLE_VOICES: typing.ClassVar[str] = ...
        EXTRA_CHECK_VOICE_DATA_FOR: typing.ClassVar[str] = ...
        EXTRA_SAMPLE_TEXT: typing.ClassVar[str] = ...
        EXTRA_TTS_DATA_INSTALLED: typing.ClassVar[str] = ...
        EXTRA_UNAVAILABLE_VOICES: typing.ClassVar[str] = ...
        EXTRA_VOICE_DATA_FILES: typing.ClassVar[str] = ...
        EXTRA_VOICE_DATA_FILES_INFO: typing.ClassVar[str] = ...
        EXTRA_VOICE_DATA_ROOT_DIRECTORY: typing.ClassVar[str] = ...
        INTENT_ACTION_TTS_SERVICE: typing.ClassVar[str] = ...
        KEY_FEATURE_EMBEDDED_SYNTHESIS: typing.ClassVar[str] = ...
        KEY_FEATURE_NETWORK_RETRIES_COUNT: typing.ClassVar[str] = ...
        KEY_FEATURE_NETWORK_SYNTHESIS: typing.ClassVar[str] = ...
        KEY_FEATURE_NETWORK_TIMEOUT_MS: typing.ClassVar[str] = ...
        KEY_FEATURE_NOT_INSTALLED: typing.ClassVar[str] = ...
        KEY_PARAM_PAN: typing.ClassVar[str] = ...
        KEY_PARAM_SESSION_ID: typing.ClassVar[str] = ...
        KEY_PARAM_STREAM: typing.ClassVar[str] = ...
        KEY_PARAM_UTTERANCE_ID: typing.ClassVar[str] = ...
        KEY_PARAM_VOLUME: typing.ClassVar[str] = ...
        SERVICE_META_DATA: typing.ClassVar[str] = ...
        def __init__(self, this_0: TextToSpeech, /) -> None: ...

class TextToSpeechService(android.app.Service):
    def __init__(self) -> None: ...
    def onBind(self, intent: android.content.Intent, /) -> android.os.IBinder: ...
    def onCreate(self) -> None: ...
    def onDestroy(self) -> None: ...
    def onGetDefaultVoiceNameFor(self, lang: str | java.lang.String, country: str | java.lang.String, variant: str | java.lang.String, /) -> str: ...
    def onGetFeaturesForLanguage(self, lang: str | java.lang.String, country: str | java.lang.String, variant: str | java.lang.String, /) -> java.util.Set[java.lang.String]: ...
    def onGetLanguage(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def onGetVoices(self) -> java.util.List[Voice]: ...
    def onIsLanguageAvailable(self, arg1: str | java.lang.String, arg2: str | java.lang.String, arg3: str | java.lang.String, /) -> int: ...
    def onIsValidVoiceName(self, voiceName: str | java.lang.String, /) -> int: ...
    def onLoadLanguage(self, arg1: str | java.lang.String, arg2: str | java.lang.String, arg3: str | java.lang.String, /) -> int: ...
    def onLoadVoice(self, voiceName: str | java.lang.String, /) -> int: ...
    def onStop(self) -> None: ...
    def onSynthesizeText(self, arg1: SynthesisRequest, arg2: SynthesisCallback, /) -> None: ...

class UtteranceProgressListener(java.lang.Object):
    def __init__(self) -> None: ...
    def onAudioAvailable(self, utteranceId: str | java.lang.String, audio: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def onBeginSynthesis(self, utteranceId: str | java.lang.String, sampleRateInHz: int | java.jint | java.lang.Integer, audioFormat: int | java.jint | java.lang.Integer, channelCount: int | java.jint | java.lang.Integer, /) -> None: ...
    def onDone(self, arg1: str | java.lang.String, /) -> None: ...
    @typing.overload
    def onError(self, arg1: str | java.lang.String, /) -> None: ...
    @typing.overload
    def onError(self, utteranceId: str | java.lang.String, errorCode: int | java.jint | java.lang.Integer, /) -> None: ...
    def onRangeStart(self, utteranceId: str | java.lang.String, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, frame: int | java.jint | java.lang.Integer, /) -> None: ...
    def onStart(self, arg1: str | java.lang.String, /) -> None: ...
    def onStop(self, utteranceId: str | java.lang.String, interrupted: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

class Voice(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[Voice]] = ...
    LATENCY_HIGH: typing.ClassVar[int] = ...
    LATENCY_LOW: typing.ClassVar[int] = ...
    LATENCY_NORMAL: typing.ClassVar[int] = ...
    LATENCY_VERY_HIGH: typing.ClassVar[int] = ...
    LATENCY_VERY_LOW: typing.ClassVar[int] = ...
    QUALITY_HIGH: typing.ClassVar[int] = ...
    QUALITY_LOW: typing.ClassVar[int] = ...
    QUALITY_NORMAL: typing.ClassVar[int] = ...
    QUALITY_VERY_HIGH: typing.ClassVar[int] = ...
    QUALITY_VERY_LOW: typing.ClassVar[int] = ...
    def __init__(self, name: str | java.lang.String, locale: java.util.Locale, quality: int | java.jint | java.lang.Integer, latency: int | java.jint | java.lang.Integer, requiresNetworkConnection: bool | java.jboolean | java.lang.Boolean, features: java.util.Set[java.lang.String], /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getFeatures(self) -> java.util.Set[java.lang.String]: ...
    def getLatency(self) -> int: ...
    def getLocale(self) -> java.util.Locale: ...
    def getName(self) -> str: ...
    def getQuality(self) -> int: ...
    def hashCode(self) -> int: ...
    def isNetworkConnectionRequired(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...
